<?php

declare(strict_types=1);

namespace Evidente\Aircash\Api\Data\Transaction;

use Evidente\Aircash\Api\WebsiteAwareInterface;

interface CodeRequestInterface extends WebsiteAwareInterface
{
    public const DEFAULT_VALID_FOR_PERIOD = 5;

    public const CURRENCY_EUR = 'EUR';
    public const CURRENCY_BGN = 'BGN';
    public const CURRENCY_HRK = 'HRK';
    public const CURRENCY_CZK = 'CZK';
    public const CURRENCY_HUF = 'HUF';
    public const CURRENCY_PLN = 'PLN';
    public const CURRENCY_RON = 'RON';
    public const CURRENCY_TRY = 'TRY';
    public const CURRENCY_USD = 'USD';

    public const CURRENCY_MAPPING = [
        self::CURRENCY_EUR => 978,
        self::CURRENCY_BGN => 975,
        self::CURRENCY_HRK => 191,
        self::CURRENCY_CZK => 203,
        self::CURRENCY_HUF => 348,
        self::CURRENCY_PLN => 985,
        self::CURRENCY_RON => 946,
        self::CURRENCY_TRY => 949,
        self::CURRENCY_USD => 840,
    ];

    public const CURRENCY_ID_MAPPING = [
        978 => self::CURRENCY_EUR,
        975 => self::CURRENCY_BGN,
        191 => self::CURRENCY_HRK,
        203 => self::CURRENCY_CZK,
        348 => self::CURRENCY_HUF,
        985 => self::CURRENCY_PLN,
        946 => self::CURRENCY_RON,
        949 => self::CURRENCY_TRY,
        840 => self::CURRENCY_USD,
    ];

    /**
     * @return string
     */
    public function getPartnerID(): string;

    /**
     * @return float
     */
    public function getAmount(): float;

    /**
     * @return int
     */
    public function getCurrencyID(): int;

    /**
     * @return string
     */
    public function getPartnerTransactionID(): string;

    /**
     * @return string
     */
    public function getDescription(): string;

    /**
     * @return string
     */
    public function getLocationID(): string;

    /**
     * @return int
     */
    public function getValidForPeriod(): int;

    public function toArray(): array;
}
