<?php

declare(strict_types=1);

namespace Evidente\Aircash\Block\Adminhtml\System\Config\Form;

use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Evidente\Aircash\Model\Config\PartnerConfig;
use Magento\Backend\Block\Template;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Widget\Button;

/**
 * @SuppressWarnings(CamelCase)
 */
class ActionButtonBlock extends Template
{
    public const TEST_MODE = '__test_mode';


    // phpcs:ignore
    protected $_template = 'Evidente_Aircash::system/config/form/action-button.phtml';

    /**
     * @var PartnerConfig
     */
    private $partnerConfig;

    /**
     * @inheritDoc
     */
    public function __construct(
        Context $context,
        PartnerConfig $partnerConfig,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->partnerConfig = $partnerConfig;
    }

    public function getButtonId(): string
    {
        $idSuffix = ((bool)$this->getData(self::TEST_MODE))
            ? '-test'
            : '-prod';

        return 'aircash-partner-action-button' . $idSuffix;
    }

    public function getButton(): ?Button
    {
        $partnerStatus = $this->getPartnerStatus();

        if (in_array(
            $partnerStatus,
            [
                ActivationRequestInterface::STATUS_ACTIVATED,
                ActivationRequestInterface::STATUS_NOT_ACTIVATED,
                ActivationRequestInterface::STATUS_PENDING
            ]
        )) {
            $buttonLabel = ($partnerStatus == ActivationRequestInterface::STATUS_NOT_ACTIVATED)
                ? __('Activate')
                : __('Check Activation Status');

            if ($partnerStatus == ActivationRequestInterface::STATUS_ACTIVATED) {
                $buttonLabel = __('Deactivate');
            }

            $buttonData = [
                'id' => $this->getButtonId(),
                'label' => $buttonLabel,
            ];

            return $this
                ->getLayout()
                ->createBlock(Button::class)
                ->setData($buttonData);
        }

        return null;
    }

    public function isTestMode()
    {
        return (bool)$this->getData(self::TEST_MODE);
    }

    public function getPartnerStatus()
    {
        return $this
            ->partnerConfig
            ->getPartnerStatus(
                $this->getRequest()->getParam('website'),
                $this->isTestMode()
            );
    }
}
