<?php

declare(strict_types=1);

namespace Evidente\Aircash\Block\Adminhtml\System\Config\Form;

use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Evidente\Aircash\Model\Config\PartnerConfig;
use Magento\Backend\Block\Template\Context;
use Magento\Config\Block\System\Config\Form\Field;
use Magento\Framework\Data\Form\Element\AbstractElement;

/**
 * @SuppressWarnings(CamelCase)
 */
class PartnerStatusField extends Field
{
    use FieldContextTrait;

    /**
     * @var PartnerConfig
     */
    private $partnerConfig;

    /**
     * @inheritDoc
     */
    public function __construct(
        Context $context,
        PartnerConfig $partnerConfig,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->partnerConfig = $partnerConfig;
    }


    // phpcs:ignore
    protected function _getElementHtml(AbstractElement $element)
    {
        list($websiteId, $testMode) = $this->getFieldContext($element);

        $partnerStatus = $this->partnerConfig->getPartnerStatus($websiteId, $testMode);

        $label = ActivationRequestInterface::STATUS_LABELS[ActivationRequestInterface::STATUS_NOT_ACTIVATED];

        foreach (ActivationRequestInterface::STATUS_LABELS as $labelKey => $labelValue) {
            if ($labelKey == $partnerStatus) {
                $label = $labelValue;
                break;
            }
        }

        $html = '<h2><b>' . $label . '</b></h2>';

        $block = $this
            ->_layout
            ->createBlock(ActionButtonBlock::class);

        $block->setData('select_html', parent::_getElementHtml($element));

        $block->setData(ActionButtonBlock::TEST_MODE, $testMode);

        $blockHtml = $block->toHtml();

        $html .= $blockHtml;

        return $html;
    }
}
