<?php

declare(strict_types=1);

namespace Evidente\Aircash\Builder\Client;

use Evidente\Aircash\Api\AircashPartnerClientInterfaceFactory;
use Evidente\Aircash\Api\AircashPartnerClientInterface;
use Evidente\Aircash\Model\ActivationConfigFactory;
use Evidente\Aircash\Model\ActivationConfig;
use Evidente\Aircash\Api\Factory\HttpClientFactoryInterfaceFactory;
use Evidente\Aircash\Api\Factory\HttpClientFactoryInterface;

/**
 * @SuppressWarnings(Long)
 */
class AircashPartnerClientBuilder
{
    private $testModeWebsiteIds = [];
    private $baseUri = null;

    /**
     * @var AircashPartnerClientInterfaceFactory
     */
    private $aircashPartnerClientFactory;

    /**
     * @var ActivationConfigFactory
     */
    private $configFactory;

    /**
     * @var HttpClientFactoryInterfaceFactory
     */
    private $httpClientFactory;

    public function __construct(
        AircashPartnerClientInterfaceFactory $aircashPartnerClientFactory,
        ActivationConfigFactory $configFactory,
        HttpClientFactoryInterfaceFactory $httpClientFactory
    ) {
        $this->aircashPartnerClientFactory = $aircashPartnerClientFactory;
        $this->configFactory = $configFactory;
        $this->httpClientFactory = $httpClientFactory;
    }

    public function withTestMode(array $websiteIds, bool $state): self
    {
        foreach ($websiteIds as $websiteId) {
            $this->testModeWebsiteIds[$websiteId] = $state;
        }

        return $this;
    }

    public function withClientBaseUri(?string $baseUri): self
    {
        $this->baseUri = $baseUri;
        return $this;
    }

    public function build(): AircashPartnerClientInterface
    {
        /**
         * @var ActivationConfig $config
         */
        $config = $this->configFactory->create();

        foreach ($this->testModeWebsiteIds as $websiteId => $state) {
            $config->setTestMode($websiteId, $state);
        }

        /**
         * @var HttpClientFactoryInterface $clientFactory
         */
        $clientFactory = $this->httpClientFactory->create(
            [
                'config' => $config,
            ]
        );

        $baseUri = $this->baseUri;

        $result = $this->aircashPartnerClientFactory->create(
            [
                'config' => $config,
                'client' => $clientFactory->create($baseUri),
            ]
        );

        $this->clear();

        return $result;
    }

    private function clear()
    {
        $this->testModeWebsiteIds = [];
        $this->baseUri = null;
    }
}
