<?php

declare(strict_types=1);

namespace Evidente\Aircash\Controller\Adminhtml\Activation;

use Evidente\Aircash\Facade\PartnerActivationFacade;
use Exception;
use Magento\Backend\App\Action;
use Magento\Framework\App\Action\HttpPostActionInterface;

/**
 * @SuppressWarnings(Long)
 */
class Activate extends Action implements HttpPostActionInterface
{
    public const PARAM_PARTNER_NAME = 'aircash-partner-name';
    public const PARAM_PARTNER_EMAIL = 'aircash-partner-email';
    public const PARAM_PARTNER_PHONE = 'aircash-partner-phone';
    public const PARAM_WEBSITE = 'website';
    public const PARAM_TEST = 'test';

    const ADMIN_RESOURCE = 'Evidente_Aircash::aircash_activation';

    /**
     * @var PartnerActivationFacade
     */
    private $partnerActivationFacade;

    /**
     * @inheritDoc
     */
    public function __construct(
        Action\Context $context,
        PartnerActivationFacade $partnerActivationFacade
    ) {
        parent::__construct($context);
        $this->partnerActivationFacade = $partnerActivationFacade;
    }

    /**
     * @inheritDoc
     */
    public function execute()
    {
        $request = $this->getRequest();

        $partnerName = filter_var($request->getParam(self::PARAM_PARTNER_NAME), FILTER_SANITIZE_STRING);
        $partnerEmail = filter_var($request->getParam(self::PARAM_PARTNER_EMAIL), FILTER_VALIDATE_EMAIL);
        $partnerPhone = filter_var($request->getParam(self::PARAM_PARTNER_PHONE), FILTER_SANITIZE_STRING);
        $websiteId = filter_var($request->getParam(self::PARAM_WEBSITE), FILTER_VALIDATE_INT);
        $testMode = filter_var($request->getParam(self::PARAM_TEST), FILTER_VALIDATE_INT);

        $messages = [];

        if (!is_string($partnerName) || empty(trim($partnerName))) {
            $messages[] = __('Invalid partner name');
        }

        if (!is_string($partnerEmail) || empty(trim($partnerEmail))) {
            $messages[] = __('Invalid partner email');
        }

        if (!is_string($partnerPhone) || empty(trim($partnerPhone))) {
            $messages[] = __('Invalid partner phone number');
        }

        if (!empty($messages)) {
            $this
                ->getMessageManager()
                ->addErrorMessage(implode(', ', $messages));

            return $this->_redirect($this->_redirect->getRefererUrl());
        }

        try {
            $this
                ->partnerActivationFacade
                ->activate((bool)$testMode, (int)$websiteId, $partnerName, $partnerEmail, $partnerPhone);
        } catch (Exception $exception) {
            $this->getMessageManager()->addErrorMessage(__('Activation failed.'));
            return $this->_redirect($this->_redirect->getRefererUrl());
        }

        $this->messageManager->addSuccessMessage(__('Partner activation successfully submitted.'));

        return $this
            ->_redirect(
                $this->getUrl('adminhtml/system_config/edit', [
                    'section' => 'payment',
                    'website' => $websiteId
                ])
            );
    }
}
