<?php

declare(strict_types=1);

namespace Evidente\Aircash\Controller\Adminhtml\Activation;

use Evidente\Aircash\Facade\PartnerDeactivationFacade;
use Magento\Backend\App\Action;
use Magento\Framework\App\Action\HttpGetActionInterface;

/**
 * @SuppressWarnings(Long)
 */
class Deactivate extends Action implements HttpGetActionInterface
{
    public const PARAM_WEBSITE = 'website';
    public const PARAM_TEST = 'test';

    const ADMIN_RESOURCE = 'Evidente_Aircash::aircash_activation';

    /**
     * @var PartnerDeactivationFacade
     */
    private $partnerDeactivationFacade;

    /**
     * @inheritDoc
     */
    public function __construct(
        Action\Context $context,
        PartnerDeactivationFacade $partnerDeactivationFacade
    ) {
        parent::__construct($context);
        $this->partnerDeactivationFacade = $partnerDeactivationFacade;
    }

    /**
     * @inheritDoc
     */
    public function execute()
    {
        $request = $this->getRequest();

        $websiteId = filter_var($request->getParam(self::PARAM_WEBSITE), FILTER_VALIDATE_INT);
        $testMode = filter_var($request->getParam(self::PARAM_TEST), FILTER_VALIDATE_INT);

        $websiteId = (int)$websiteId;

        $this->partnerDeactivationFacade->deactivate((bool)$testMode, $websiteId);

        $this->messageManager->addSuccessMessage(__('Partner deactivation successful.'));

        return $this
            ->_redirect(
                $this->getUrl('adminhtml/system_config/edit', [
                    'section' => 'payment',
                    'website' => $websiteId
                ])
            );
    }
}
