<?php

declare(strict_types=1);

namespace Evidente\Aircash\Controller\Checkout;

use Magento\Checkout\Model\SessionFactory;
use Magento\Checkout\Model\Session;
use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\ActionInterface;
use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Sales\Model\Order;

/**
 * @SuppressWarnings(Long)
 */
class Status extends Action implements ActionInterface
{
    public const STATUS_INCOMPLETE = 'incomplete';
    public const STATUS_COMPLETE = 'complete';
    public const STATUS_INVALID = 'invalid';

    /**
     * @var SessionFactory
     */
    private $sessionFactory;

    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * @inheritDoc
     */
    public function __construct(
        Context $context,
        SessionFactory $sessionFactory,
        OrderRepositoryInterface $orderRepository
    ) {
        parent::__construct($context);
        $this->sessionFactory = $sessionFactory;
        $this->orderRepository = $orderRepository;
    }

    /**
     * @inheritDoc
     * @SuppressWarnings(Else)
     */
    public function execute()
    {
        $response = [
            'status' => self::STATUS_INCOMPLETE,
        ];

        /**
         * @var Session
         */
        $session = $this->sessionFactory->create();

        $placedOrderId = $session->getLastOrderId();

        if (!$placedOrderId) {
            $response['status'] = self::STATUS_INVALID;
        } else {
            try {
                $order = $this->orderRepository->get($placedOrderId);

                if ($order->getStatus() !== Order::STATE_PENDING_PAYMENT) {
                    $response['status'] = self::STATUS_COMPLETE;
                }
            } catch (NoSuchEntityException $exception) {
                $response['status'] = self::STATUS_INVALID;
            }
        }

        /** @var Json $result */
        $result = $this->resultFactory->create(ResultFactory::TYPE_JSON);

        $result->setData($response);
        $result->setHeader('Cache-Control', 'no-store, no-cache, must-revalidate, max-age=0', true);

        return $result;
    }
}
