<?php

declare(strict_types=1);

namespace Evidente\Aircash\Data\Partner;

use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;

/**
 * @SuppressWarnings(Long)
 */
class ActivationRequest implements ActivationRequestInterface
{
    private $platformID;
    private $partnerID;
    private $partnerName;
    private $publicKey;
    private $currencyID;
    private $confirmTransactionURL;
    private $contactEmail;
    private $phoneNumber;
    private $websiteId;
    private $note;

    /**
     * @SuppressWarnings(Excessive)
     */
    public function __construct(
        string $platformID,
        string $partnerID,
        string $partnerName,
        string $publicKey,
        int $currencyID,
        string $confirmTransactionURL,
        string $contactEmail,
        string $phoneNumber,
        int $websiteId,
        ?string $note = null
    ) {
        $this->platformID = $platformID;
        $this->partnerID = $partnerID;
        $this->partnerName = $partnerName;
        $this->publicKey = $publicKey;
        $this->currencyID = $currencyID;
        $this->confirmTransactionURL = $confirmTransactionURL;
        $this->contactEmail = $contactEmail;
        $this->phoneNumber = $phoneNumber;
        $this->websiteId = $websiteId;
        $this->note = $note;
    }

    public function getPlatformID(): string
    {
        return $this->platformID;
    }

    public function getPartnerID(): string
    {
        return $this->partnerID;
    }

    public function getPartnerName(): string
    {
        return $this->partnerName;
    }

    public function getPublicKey(): string
    {
        return $this->publicKey;
    }

    public function getCurrencyID(): int
    {
        return $this->currencyID;
    }

    public function getConfirmTransactionURL(): string
    {
        return $this->confirmTransactionURL;
    }

    public function getContactEmail(): string
    {
        return $this->contactEmail;
    }

    public function getPhoneNumber(): string
    {
        return $this->phoneNumber;
    }

    public function getWebsiteId(): int
    {
        return $this->websiteId;
    }

    public function getNote(): ?string
    {
        return $this->note;
    }

    public function toArray(): array
    {
        return [
            'PlatformID' => $this->getPlatformID(),
            'PartnerID' => $this->getPartnerID(),
            'PartnerName' => $this->getPartnerName(),
            'PublicKey' => $this->getPublicKey(),
            'CurrencyID' => $this->getCurrencyID(),
            'ConfirmTransactionURL' => $this->getConfirmTransactionURL(),
            'ContactEmail' => $this->getContactEmail(),
            'PhoneNumber' => $this->getPhoneNumber(),
            'Note' => $this->getNote(),
        ];
    }
}
