<?php

declare(strict_types=1);

namespace Evidente\Aircash\Data\Transaction;

use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;

class CodeRequest implements CodeRequestInterface
{
    private $partnerID;
    private $amount;
    private $currencyID;
    private $partnerTransactionID;
    private $description;
    private $locationID;
    private $websiteId;
    private $validForPeriod;

    public function __construct(
        string $partnerID,
        float $amount,
        int $currencyID,
        string $partnerTransactionID,
        string $description,
        string $locationID,
        int $websiteId,
        int $validForPeriod = self::DEFAULT_VALID_FOR_PERIOD
    ) {
        $this->partnerID = $partnerID;
        $this->amount = $amount;
        $this->currencyID = $currencyID;
        $this->partnerTransactionID = $partnerTransactionID;
        $this->description = $description;
        $this->locationID = $locationID;
        $this->websiteId = $websiteId;
        $this->validForPeriod = $validForPeriod;
    }

    /**
     * @inheritDoc
     */
    public function getPartnerID(): string
    {
        return $this->partnerID;
    }

    /**
     * @inheritDoc
     */
    public function getAmount(): float
    {
        return $this->amount;
    }

    /**
     * @inheritDoc
     */
    public function getCurrencyID(): int
    {
        return $this->currencyID;
    }

    /**
     * @inheritDoc
     */
    public function getPartnerTransactionID(): string
    {
        return $this->partnerTransactionID;
    }

    /**
     * @inheritDoc
     */
    public function getDescription(): string
    {
        return $this->description;
    }

    /**
     * @inheritDoc
     */
    public function getLocationID(): string
    {
        return $this->locationID;
    }

    /**
     * @inheritDoc
     */
    public function getWebsiteId(): int
    {
        return $this->websiteId;
    }

    /**
     * @inheritDoc
     */
    public function getValidForPeriod(): int
    {
        return $this->validForPeriod;
    }

    public function toArray(): array
    {
        return [
            'PartnerID' => $this->getPartnerID(),
            'Amount' => $this->getAmount(),
            'CurrencyID' => $this->getCurrencyID(),
            'PartnerTransactionID' => $this->getPartnerTransactionID(),
            'Description' => $this->getDescription(),
            'LocationID' => $this->getLocationID(),
        ];
    }
}
