<?php

declare(strict_types=1);

namespace Evidente\Aircash\Data\Transaction;

use Evidente\Aircash\Api\Data\Transaction\ConfirmationResultInterface;
use Magento\Framework\DataObject;
use Webmozart\Assert\Assert;
use InvalidArgumentException;

/**
 * @SuppressWarnings(Long)
 * @SuppressWarnings(Static)
 */
class ConfirmationResult implements ConfirmationResultInterface
{
    /**
     * @var DataObject
     */
    private $data;

    /**
     * @throws InvalidArgumentException
     */
    public function __construct(array $input)
    {
        $this->import($input);
    }

    public function getPartnerID(): string
    {
        return $this->data->getData(self::FIELD_PARTNER_ID);
    }

    public function getPartnerTransactionID(): string
    {
        return $this->data->getData(self::FIELD_PARTNER_TRANSACTION_ID);
    }

    public function getAmount(): float
    {
        return $this->data->getData(self::FIELD_AMOUNT);
    }

    public function getCurrencyID(): int
    {
        return $this->data->getData(self::FIELD_CURRENCY_ID);
    }

    public function getAircashTransactionID(): string
    {
        return $this->data->getData(self::FIELD_AIRCASH_TRANSACTION_ID);
    }

    public function getSignature(): string
    {
        return $this->data->getData(self::FIELD_SIGNATURE);
    }

    /**
     * @throws InvalidArgumentException
     */
    private function import(array $input)
    {
        $this->data = new DataObject();

        $input = array_change_key_case($input, CASE_LOWER);

        $partnerID = $input[\mb_strtolower(self::FIELD_PARTNER_ID)] ?? null;
        $partnerTransactionID = $input[\mb_strtolower(self::FIELD_PARTNER_TRANSACTION_ID)] ?? null;
        $amount = $input[\mb_strtolower(self::FIELD_AMOUNT)] ?? null;
        $currencyID = $input[\mb_strtolower(self::FIELD_CURRENCY_ID)] ?? null;
        $aircashTransactionID = $input[\mb_strtolower(self::FIELD_AIRCASH_TRANSACTION_ID)] ?? null;
        $signature = $input[\mb_strtolower(self::FIELD_SIGNATURE)] ?? null;

        Assert::scalar($partnerID, 'Invalid partner id');
        Assert::scalar($partnerTransactionID, 'Invalid partner transaction id');
        Assert::numeric($amount, 'Invalid amount');
        Assert::integer($currencyID, 'Invalid currency id');
        Assert::stringNotEmpty($aircashTransactionID, 'Invalid aircash transaction id');
        Assert::stringNotEmpty($signature, 'Invalid signature');

        $this
            ->data
            ->setData(
                [
                    self::FIELD_PARTNER_ID => (string)$partnerID,
                    self::FIELD_PARTNER_TRANSACTION_ID => (string)$partnerTransactionID,
                    self::FIELD_AMOUNT => (float)$amount,
                    self::FIELD_CURRENCY_ID => $currencyID,
                    self::FIELD_AIRCASH_TRANSACTION_ID => $aircashTransactionID,
                    self::FIELD_SIGNATURE => $signature,
                ]
            );
    }
}
