<?php

declare(strict_types=1);

namespace Evidente\Aircash\Data\Transaction;

use Evidente\Aircash\Api\Data\Transaction\RefundRequestInterface;

/**
 * @SuppressWarnings(Long)
 */
class RefundRequest implements RefundRequestInterface
{
    private $partnerID;
    private $partnerTransactionID;
    private $refundPartnerTransactionID;
    private $amount;
    private $websiteId;

    public function __construct(
        string $partnerID,
        string $partnerTransactionID,
        string $refundPartnerTransactionID,
        float $amount,
        int $websiteId
    ) {
        $this->partnerID = $partnerID;
        $this->partnerTransactionID = $partnerTransactionID;
        $this->refundPartnerTransactionID = $refundPartnerTransactionID;
        $this->amount = $amount;
        $this->websiteId = $websiteId;
    }

    /**
     * @inheritDoc
     */
    public function getPartnerID(): string
    {
        return $this->partnerID;
    }

    /**
     * @inheritDoc
     */
    public function getPartnerTransactionID(): string
    {
        return $this->partnerTransactionID;
    }

    /**
     * @inheritDoc
     */
    public function getRefundPartnerTransactionID(): string
    {
        return $this->refundPartnerTransactionID;
    }

    /**
     * @inheritDoc
     */
    public function getAmount(): float
    {
        return $this->amount;
    }

    /**
     * @inheritDoc
     */
    public function getWebsiteId(): int
    {
        return $this->websiteId;
    }

    public function toArray(): array
    {
        return [
            'PartnerID' => $this->getPartnerID(),
            'PartnerTransactionID' => $this->getPartnerTransactionID(),
            'RefundPartnerTransactionID' => $this->getRefundPartnerTransactionID(),
            'Amount' => $this->getAmount(),
        ];
    }
}
