<?php

declare(strict_types=1);

namespace Evidente\Aircash\Facade;

use Evidente\Aircash\Api\ConfigInterface;
use Magento\Framework\App\Cache\TypeListInterface;
use Magento\Framework\App\Cache\Type\Config as ConfigType;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Magento\Store\Model\ScopeInterface;

/**
 * @SuppressWarnings(Long)
 * @SuppressWarnings(Coupling)
 */
class PartnerDeactivationFacade
{
    private $writer;
    private $cacheTypeList;

    public function __construct(
        WriterInterface $writer,
        TypeListInterface $cacheTypeList
    ) {
        $this->writer = $writer;
        $this->cacheTypeList = $cacheTypeList;
    }

    public function deactivate(bool $testMode, int $websiteId)
    {
        $this->saveConfigData($testMode, $websiteId);
    }

    private function saveConfigData(
        bool $testMode,
        int $websiteId
    ) {
        $scope = ($websiteId === 0) ? ScopeConfigInterface::SCOPE_TYPE_DEFAULT : ScopeInterface::SCOPE_WEBSITES;

        $basePath = ($testMode)
            ? ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/'
            : ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/';

        $this
            ->writer
            ->delete(
                $basePath . ConfigInterface::CONFIG_PATH_PARTNER_ID,
                $scope,
                $websiteId
            );

        $this
            ->writer
            ->delete(
                $basePath . ConfigInterface::CONFIG_PATH_PARTNER_CURRENCY,
                $scope,
                $websiteId
            );

        $this
            ->writer
            ->delete(
                $basePath . ConfigInterface::CONFIG_PRIVATE_KEY,
                $scope,
                $websiteId
            );

        $this
            ->writer
            ->delete(
                $basePath . ConfigInterface::CONFIG_PASSPHRASE,
                $scope,
                $websiteId
            );

        $this
            ->writer
            ->delete(
                $basePath . ConfigInterface::CONFIG_PATH_PARTNER_STATUS,
                $scope,
                $websiteId
            );

        $this->cacheTypeList->invalidate(ConfigType::TYPE_IDENTIFIER);
    }
}
