<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Factory\HttpClientFactoryInterface;
use GuzzleHttp\Client;

class HttpClientFactory implements HttpClientFactoryInterface
{
    /**
     * @var ConfigInterface
     */
    private $config;

    public function __construct(ConfigInterface $config)
    {
        $this->config = $config;
    }

    public function create(?string $baseUri = null): Client
    {
        if ($baseUri === null) {
            $baseUri = ($this->config->isTestMode())
                ? ConfigInterface::TEST_BASE_URL
                : ConfigInterface::PROD_BASE_URL;

            if ($this->config->isDeveloperMode()) {
                $baseUri = ConfigInterface::DEV_BASE_URL;
            }
        }

        return new Client(
            [
                'base_uri' => $baseUri
            ]
        );
    }
}
