<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Partner;

use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Api\Factory\Partner\ActivationRequestFactoryInterface;
use Evidente\Aircash\Data\Partner\ActivationRequest;
use Evidente\Aircash\Exception\InvalidInputException;
use Magento\Framework\Pricing\PriceCurrencyInterface;
use Magento\Store\Model\StoreManagerInterface;
use Ramsey\Uuid\Uuid;
use Exception;

/**
 * @SuppressWarnings(Static)
 * @SuppressWarnings(Long)
 */
class ActivationRequestFactory implements ActivationRequestFactoryInterface
{
    /**
     * @var PriceCurrencyInterface
     */
    private $priceCurrency;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    public function __construct(PriceCurrencyInterface $priceCurrency, StoreManagerInterface $storeManager)
    {
        $this->priceCurrency = $priceCurrency;
        $this->storeManager = $storeManager;
    }

    public function create(
        int $websiteId,
        string $partnerName,
        string $publicKey,
        string $contactEmail,
        string $phoneNumber,
        ?string $note = null
    ): ActivationRequestInterface {
        $storeId = (int)$this->storeManager->getWebsite($websiteId)->getStoreId();

        $storeCurrencyCode = $this->priceCurrency->getCurrency($storeId)->getCode();

        $currencyMapping = CodeRequestInterface::CURRENCY_MAPPING;

        if (!array_key_exists($storeCurrencyCode, $currencyMapping)) {
            throw new InvalidInputException(__('Unsupported currency: %1', $storeCurrencyCode));
        }

        $currencyID = $currencyMapping[$storeCurrencyCode];

        // @codeCoverageIgnoreStart
        try {
            $partnerId = Uuid::uuid4();
        } catch (Exception $exception) {
            throw new InvalidInputException(__('Unable to generated partner ID'), $exception);
        }
        // @codeCoverageIgnoreEnd

        $confirmTransactionURL = $this
            ->storeManager
            ->getStore($storeId)
            ->getBaseUrl() . 'rest/V1/payment/aircash/confirm-transaction';

        $publicKey = str_replace(
            [
                '-----BEGIN CERTIFICATE-----',
                '-----END CERTIFICATE-----',
                "\n"
            ],
            '',
            $publicKey
        );

        return new ActivationRequest(
            self::PLATFORM_ID,
            $partnerId->__toString(),
            $partnerName,
            $publicKey,
            $currencyID,
            $confirmTransactionURL,
            $contactEmail,
            $phoneNumber,
            $websiteId,
            $note
        );
    }
}
