<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Partner;

use Evidente\Aircash\Api\Factory\Partner\CertificateFactoryInterface;

class CertificateFactory implements CertificateFactoryInterface
{
    public function create(): array
    {
        $certificateData = [
            'countryName' => 'HR',
            'localityName' => 'Zagreb',
            'organizationName' => 'Evidente d.o.o.',
            'organizationalUnitName' => 'Magento',
            'commonName' => 'Evidente',
            'emailAddress' => 'info@evidente.hr'
        ];

        $privateKey = openssl_pkey_new(
            [
                'private_key_bits' => 4096,
                'private_key_type' => OPENSSL_KEYTYPE_RSA,
            ]
        );

        $csr = openssl_csr_new($certificateData, $privateKey, ['digest_alg' => 'sha256']);

        $x509 = openssl_csr_sign(
            $csr,
            null,
            $privateKey,
            365 * 10,
            ['digest_alg' => 'sha256']
        );

        openssl_x509_export($x509, $publicKeyExport);

        $passphrase = bin2hex(openssl_random_pseudo_bytes(32));

        openssl_pkey_export($privateKey, $privateKeyExport, $passphrase);

        return [$publicKeyExport, $privateKeyExport, $passphrase];
    }
}
