<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Transaction;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Transaction\CancellationRequestInterface;
use Evidente\Aircash\Api\Factory\Transaction\CancellationRequestFactoryInterface;
use Evidente\Aircash\Data\Transaction\CancellationRequest;
use Evidente\Aircash\Exception\InvalidInputException;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Store\Model\StoreManagerInterface;

class CancellationRequestFactory implements CancellationRequestFactoryInterface
{
    /**
     * @var ConfigInterface
     */
    private $config;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    public function __construct(ConfigInterface $config, StoreManagerInterface $storeManager)
    {
        $this->config = $config;
        $this->storeManager = $storeManager;
    }

    public function createFromOrder(OrderInterface $order): CancellationRequestInterface
    {
        $storeId = $order->getStoreId();

        $websiteId = (int)$this->storeManager->getStore($storeId)->getWebsiteId();

        $transactionId = $order->getIncrementId();

        if (!$transactionId) {
            throw new InvalidInputException(__('Increment order ID is required for transaction ID'));
        }

        $prefix = trim((string)$this->config->getTransactionIdPrefix($websiteId));

        if (!empty($prefix)) {
            $transactionId = $prefix . $transactionId;
        }

        return new CancellationRequest(
            $this->config->getPartnerID($storeId),
            $transactionId,
            $websiteId
        );
    }
}
