<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Transaction;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Api\Factory\Transaction\CodeRequestFactoryInterface;
use Evidente\Aircash\Data\Transaction\CodeRequest;
use Evidente\Aircash\Exception\InvalidInputException;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Store\Model\StoreManagerInterface;

class CodeRequestFactory implements CodeRequestFactoryInterface
{
    /**
     * @var ConfigInterface
     */
    private $config;

    /**
     * @var StoreManagerInterface $storeManager
     */
    private $storeManager;

    public function __construct(ConfigInterface $config, StoreManagerInterface $storeManager)
    {
        $this->config = $config;
        $this->storeManager = $storeManager;
    }

    public function createFromOrder(OrderInterface $order): CodeRequestInterface
    {
        $storeId = $order->getStoreId();

        $websiteId = (int)$this->storeManager->getStore($storeId)->getWebsiteId();

        $currencyCode = $order->getOrderCurrencyCode();

        if (!array_key_exists($currencyCode, CodeRequestInterface::CURRENCY_MAPPING)) {
            throw new InvalidInputException(__('Invalid currency: %1', $currencyCode));
        }

        $currencyMapped = CodeRequestInterface::CURRENCY_MAPPING[$currencyCode];

        $transactionId = $order->getIncrementId();

        if (!$transactionId) {
            throw new InvalidInputException(__('Increment order ID is required for transaction ID'));
        }

        $prefix = trim((string)$this->config->getTransactionIdPrefix($websiteId));

        if (!empty($prefix)) {
            $transactionId = $prefix . $transactionId;
        }

        return new CodeRequest(
            $this->config->getPartnerID($websiteId),
            (float)$order->getGrandTotal(),
            $currencyMapped,
            $transactionId,
            'Order-' . $transactionId,
            $this->config->getLocationID($websiteId),
            $websiteId
        );
    }
}
