<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Transaction;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Transaction\ConfirmationResultInterface;
use Evidente\Aircash\Api\Factory\Transaction\ConfirmationResultFactoryInterface;
use Evidente\Aircash\Api\SignatureInterface;
use Evidente\Aircash\Data\Transaction\ConfirmationResult;
use Evidente\Aircash\Exception\InvalidInputException;
use Evidente\Aircash\Exception\InvalidSignatureException;
use Magento\Framework\App\RequestInterface;
use InvalidArgumentException;
use Psr\Log\LoggerInterface;

class ConfirmationResultFactory implements ConfirmationResultFactoryInterface
{
    /**
     * @var RequestInterface
     */
    private $request;

    /**
     * @var SignatureInterface
     */
    private $signature;

    /**
     * @var ConfigInterface
     */
    private $config;

    /**
     * @var LoggerInterface
     */
    private $logger;

    public function __construct(
        RequestInterface $request,
        SignatureInterface $signature,
        ConfigInterface $config,
        LoggerInterface $logger
    ) {
        $this->request = $request;
        $this->signature = $signature;
        $this->config = $config;
        $this->logger = $logger;
    }

    public function createFromRequest(): ConfirmationResultInterface
    {
        $content = (array)\json_decode((string)$this->request->getContent(), true);

        try {
            $transactionRequest = new ConfirmationResult($content);
        } catch (InvalidArgumentException $exception) {
            $this
                ->logger
                ->alert(
                    sprintf(
                        'Aircash confirmation result factory: Invalid input exception \'%s\' for data: %s',
                        $exception->getMessage(),
                        \json_encode($content, JSON_PRETTY_PRINT)
                    )
                );

            throw new InvalidInputException(__('Invalid input: ' . $exception->getMessage()), $exception);
        }

        try {
            $this
                ->signature
                ->validate(
                    $content,
                    $transactionRequest->getSignature(),
                    $this->config->getPublicKey()
                );
        } catch (InvalidSignatureException $exception) {
            $this
                ->logger
                ->alert(
                    sprintf(
                        'Aircash confirmation result factory: \'%s\' for data: %s',
                        $exception->getMessage(),
                        \json_encode($content, JSON_PRETTY_PRINT)
                    )
                );

            throw $exception;
        }

        return $transactionRequest;
    }
}
