<?php

declare(strict_types=1);

namespace Evidente\Aircash\Factory\Transaction;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Transaction\RefundRequestInterface;
use Evidente\Aircash\Api\Factory\Transaction\RefundRequestFactoryInterface;
use Evidente\Aircash\Data\Transaction\RefundRequest;
use Evidente\Aircash\Exception\InvalidInputException;
use Magento\Sales\Api\Data\CreditmemoInterface;
use Magento\Store\Model\StoreManagerInterface;
use Ramsey\Uuid\Uuid;

/**
 * @SuppressWarnings(Long)
 * @SuppressWarnings(Static)
 */
class RefundRequestFactory implements RefundRequestFactoryInterface
{
    /**
     * @var ConfigInterface
     */
    private $config;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    public function __construct(
        ConfigInterface $config,
        StoreManagerInterface $storeManager
    ) {
        $this->config = $config;
        $this->storeManager = $storeManager;
    }

    /**
     * @inheritDoc
     */
    public function createFromCreditMemo(CreditmemoInterface $creditMemo): RefundRequestInterface
    {
        $order = $creditMemo->getOrder();

        $storeId = $order->getStoreId();

        $websiteId = (int)$this->storeManager->getStore($storeId)->getWebsiteId();

        $prefix = trim((string)$this->config->getTransactionIdPrefix($websiteId));

        $partnerTransactionId = $order->getIncrementId();

        if (!$partnerTransactionId) {
            throw new InvalidInputException(__('Increment order ID is required for transaction ID'));
        }

        if (!empty($prefix)) {
            $partnerTransactionId = $prefix . $partnerTransactionId;
        }

        // @codeCoverageIgnoreStart
        try {
            $refundPartnerTransactionId = Uuid::uuid4();
        } catch (\Exception $exception) {
            throw new InvalidInputException(__('Unable to generate refund ID'), $exception);
        }
        // @codeCoverageIgnoreEnd

        return new RefundRequest(
            $this->config->getPartnerID($websiteId),
            (string)$partnerTransactionId,
            (string)$refundPartnerTransactionId,
            (float)$creditMemo->getGrandTotal(),
            $websiteId
        );
    }
}
