<?php

declare(strict_types=1);

namespace Evidente\Aircash\Gateway\Command;

use Evidente\Aircash\Exception\InvalidInputException;
use Evidente\Aircash\Exception\RequestException;
use Magento\Payment\Gateway\CommandInterface;
use Magento\Payment\Model\InfoInterface;
use Magento\Sales\Api\Data\CreditmemoInterface;
use Magento\Sales\Api\Data\OrderInterface;

/**
 * @SuppressWarnings(Long)
 */
class Refund extends AbstractCommand implements CommandInterface
{
    /**
     * @inheritDoc
     * @throws InvalidInputException|RequestException
     */
    public function execute(array $commandSubject)
    {
        /**
         * @var InfoInterface $payment
         */
        $payment = $commandSubject['payment']->getPayment();

        /**
         * @var OrderInterface $order
         */
        $order = $payment->getOrder();

        /**
         * @var CreditmemoInterface $creditMemo
         */
        $creditMemo = $payment->getCreditmemo();

        $orderGrandTotal = number_format(
            (float)$order->getGrandTotal(),
            2,
            '.',
            ''
        );

        $creditMemoGrandTotal = number_format(
            (float)$creditMemo->getGrandTotal(),
            2,
            '.',
            ''
        );

        if ($orderGrandTotal !== $creditMemoGrandTotal) {
            $request = $this->refundRequestFactory->createFromCreditMemo($creditMemo);

            $result = $this->aircashClient->refundTransaction($request);

            $creditMemo->setTransactionId($result->getRefundPartnerTransactionID());

            return null;
        }

        $request = $this->cancellationRequestFactory->createFromOrder($order);

        $result = $this->aircashClient->cancelTransaction($request);

        $creditMemo->setTransactionId($result->getCancelTransactionID());

        return null;
    }
}
