<?php

declare(strict_types=1);

namespace Evidente\Aircash\Model;

use Evidente\Aircash\Api\OverridableConfigInterface;

/**
 * @SuppressWarnings(Else)
 * @SuppressWarnings(Unused)
 */
class ActivationConfig extends Config implements OverridableConfigInterface
{
    private $testMode = [];

    public function setTestMode(int $websiteId, bool $testMode): void
    {
        $this->testMode[$websiteId] = $testMode;
    }

    /**
     * @inheritDoc
     */
    public function isTestMode($websiteId = null): bool
    {
        $intWebsiteId = (int)$websiteId;

        if (array_key_exists($intWebsiteId, $this->testMode)) {
            return $this->testMode[$intWebsiteId];
        }

        return parent::isTestMode($websiteId);
    }

    /**
     * @codeCoverageIgnore
     */
    public function getPublicKey($websiteId = null)
    {
        $path = dirname(__FILE__) . '/Partner/Activation/Data/';

        if ($this->isTestMode($websiteId)) {
            $path .= 'activation_key_test.pub';
        } else {
            $path .= 'activation_key_prod.pub';
        }

        return \file_get_contents($path);
    }

    public function getPrivateKey($websiteId = null)
    {
        $path = dirname(__FILE__) . '/Partner/Activation/Data/';

        if ($this->isTestMode($websiteId)) {
            $path .= 'activation_key_test';
        } else {
            $path .= 'activation_key_prod';
        }

        return \file_get_contents($path);
    }

    /**
     * @SuppressWarnings(Unused)
     */
    public function getPassphrase($storeId = null)
    {
        return null;
    }
}
