<?php

declare(strict_types=1);

namespace Evidente\Aircash\Model;

use Evidente\Aircash\Api\ConfigInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Store\Model\ScopeInterface;

class Config implements ConfigInterface
{
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    public function __construct(ScopeConfigInterface $scopeConfig)
    {
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @inheritDoc
     */
    public function getTitle($storeId = null)
    {
        return $this->getValue(self::CONFIG_PATH_TITLE, $storeId, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @inheritDoc
     */
    public function isActive($storeId = null): bool
    {
        return (bool)$this->getValue(self::CONFIG_PATH_ACTIVE, $storeId, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @inheritDoc
     */
    public function isTestMode($websiteId = null): bool
    {
        return (bool)$this
            ->getValue(
                self::CONFIG_PATH_TEST_MODE,
                $websiteId,
                ScopeInterface::SCOPE_WEBSITES
            );
    }

    public function isDeveloperMode($storeId = null): bool
    {
        return (bool)$this->getValue(self::CONFIG_PATH_DEVELOPER_MODE, $storeId, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @inheritDoc
     */
    public function getPartnerStatus($websiteId = null)
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PATH_PARTNER_STATUS;

        return $this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @inheritDoc
     */
    public function getTransactionIdPrefix($websiteId = null)
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PATH_TRANSACTION_ID_PREFIX;

        return $this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @inheritDoc
     */
    public function getPartnerID($websiteId = null): string
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PATH_PARTNER_ID;

        return (string)$this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @inheritDoc
     */
    public function getLocationID($websiteId = null): string
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PATH_LOCATION_ID;

        return (string)$this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    public function getPartnerCurrency($websiteId = null): string
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PATH_PARTNER_CURRENCY;

        return (string)$this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @inheritDoc
     * @SuppressWarnings(Else)
     * @codeCoverageIgnore
     */
    public function getPublicKey($websiteId = null)
    {
        $path = dirname(__FILE__) . '/Payment/PublicKey/';

        if ($this->isTestMode($websiteId)) {
            $path .= 'Test.pub';
        } else {
            $path .= 'Prod.pub';
        }

        return \file_get_contents($path);
    }

    /**
     * @inheritDoc
     */
    public function getPrivateKey($websiteId = null)
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PRIVATE_KEY;

        return $this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @inheritDoc
     */
    public function getPassphrase($websiteId = null)
    {
        $path = $this->getGroupPath($websiteId) . self::CONFIG_PASSPHRASE;

        return $this->getValue($path, $websiteId, ScopeInterface::SCOPE_WEBSITES);
    }

    /**
     * @param string $subPath
     * @param mixed $scopeId
     * @return mixed
     */
    private function getValue(string $subPath, $scopeId, string $scope)
    {
        return $this
            ->scopeConfig
            ->getValue(self::CONFIG_PATH_BASE . $subPath, $scope, $scopeId);
    }

    private function getGroupPath($websiteId): string
    {
        $path = ($this->isTestMode($websiteId))
            ? self::CONFIG_GROUP_TEST
            : self::CONFIG_GROUP_PROD;

        return $path . '/';
    }
}
