<?php

declare(strict_types=1);

namespace Evidente\Aircash\Model\Config;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Magento\Config\Model\ResourceModel\Config\Data\Collection;
use Magento\Config\Model\ResourceModel\Config\Data\CollectionFactory;
use Magento\Store\Model\ScopeInterface;

class PartnerConfig
{
    /**
     * @var CollectionFactory
     */
    private $collectionFactory;

    public function __construct(CollectionFactory $collectionFactory)
    {
        $this->collectionFactory = $collectionFactory;
    }

    /**
     * @return mixed
     */
    public function getPartnerStatus($websiteId, bool $testMode)
    {
        /**
         * @var Collection $collection
         */
        $collection = $this->collectionFactory->create();

        if ($websiteId) {
            $path = ConfigInterface::CONFIG_PATH_BASE
                . $this->getGroupPath($testMode)
                . ConfigInterface::CONFIG_PATH_PARTNER_STATUS;

            $collection
                ->addFieldToFilter('scope', ScopeInterface::SCOPE_WEBSITES)
                ->addFieldToFilter('scope_id', $websiteId)
                ->addFieldToFilter(
                    'path',
                    $path
                );

            if ($collection->count()) {
                $value = $collection->getFirstItem()->getValue();

                if ($value === null) {
                    $value = ActivationRequestInterface::STATUS_NOT_ACTIVATED;
                }

                return $value;
            }
        }

        return ActivationRequestInterface::STATUS_NOT_ACTIVATED;
    }

    /**
     * @return mixed
     */
    public function getPartnerId($websiteId, bool $testMode)
    {
        /**
         * @var Collection $collection
         */
        $collection = $this->collectionFactory->create();

        if ($websiteId) {
            $path = ConfigInterface::CONFIG_PATH_BASE
                . $this->getGroupPath($testMode)
                . ConfigInterface::CONFIG_PATH_PARTNER_ID;

            $collection
                ->addFieldToFilter('scope', ScopeInterface::SCOPE_WEBSITES)
                ->addFieldToFilter('scope_id', $websiteId)
                ->addFieldToFilter(
                    'path',
                    $path
                );

            if ($collection->count()) {
                return $collection->getFirstItem()->getValue();
            }
        }

        return null;
    }

    /**
     * @return mixed
     */
    public function getPartnerCurrency($websiteId, bool $testMode)
    {
        /**
         * @var Collection $collection
         */
        $collection = $this->collectionFactory->create();

        if ($websiteId) {
            $path = ConfigInterface::CONFIG_PATH_BASE
                . $this->getGroupPath($testMode)
                . ConfigInterface::CONFIG_PATH_PARTNER_CURRENCY;

            $collection
                ->addFieldToFilter('scope', ScopeInterface::SCOPE_WEBSITES)
                ->addFieldToFilter('scope_id', $websiteId)
                ->addFieldToFilter(
                    'path',
                    $path
                );

            if ($collection->count()) {
                return $collection->getFirstItem()->getValue();
            }
        }

        return null;
    }

    public function isTestMode($websiteId): bool
    {
        /**
         * @var Collection $collection
         */
        $collection = $this->collectionFactory->create();

        if ($websiteId) {
            $collection
                ->addFieldToFilter('scope', ScopeInterface::SCOPE_WEBSITES)
                ->addFieldToFilter('scope_id', $websiteId)
                ->addFieldToFilter(
                    'path',
                    ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_TEST_MODE
                );

            if ($collection->count()) {
                return (bool)$collection->getFirstItem()->getValue();
            }
        }

        return false;
    }

    private function getGroupPath(bool $testMode): string
    {
        $path = ($testMode)
            ? ConfigInterface::CONFIG_GROUP_TEST
            : ConfigInterface::CONFIG_GROUP_PROD;

        return $path . '/';
    }
}
