<?php

declare(strict_types=1);

namespace Evidente\Aircash\Model\Payment;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\Locale\Resolver;
use Magento\Payment\Model\MethodInterface;
use Magento\Payment\Model\Method\Adapter;
use Magento\Payment\Model\InfoInterface;
use Magento\Quote\Api\Data\CartInterface;
use Magento\Store\Model\StoreManagerInterface;

/**
 * @SuppressWarnings(Excessive)
 * @SuppressWarnings(TooMany)
 * @codeCoverageIgnore
 */
class Aircash implements MethodInterface
{
    public const METHOD_CODE = 'aircash';

    /**
     * @var MethodInterface
     */
    private $adapter;

    /**
     * @var Resolver
     */
    private $resolver;

    /**
     * @var ConfigInterface
     */
    private $config;

    /**
     * @var StoreManagerInterface
     */
    private $storeManager;

    public function __construct(
        Adapter $adapter,
        Resolver $resolver,
        ConfigInterface $config,
        StoreManagerInterface $storeManager
    ) {
        $this->adapter = $adapter;
        $this->resolver = $resolver;
        $this->config = $config;
        $this->storeManager = $storeManager;
    }

    /**
     * @inheritDoc
     */
    public function getCode()
    {
        return self::METHOD_CODE;
    }

    /**
     * @inheritDoc
     */
    public function getFormBlockType()
    {
        return $this->adapter->getFormBlockType();
    }

    /**
     * @inheritDoc
     */
    public function getTitle()
    {
        return $this->adapter->getTitle();
    }

    /**
     * @inheritDoc
     */
    public function setStore($storeId)
    {
        $this->adapter->setStore($storeId);
    }

    /**
     * @inheritDoc
     */
    public function getStore()
    {
        return $this->adapter->getStore();
    }

    /**
     * @inheritDoc
     */
    public function canOrder()
    {
        return $this->adapter->canOrder();
    }

    /**
     * @inheritDoc
     */
    public function canAuthorize()
    {
        return $this->adapter->canAuthorize();
    }

    /**
     * @inheritDoc
     */
    public function canCapture()
    {
        return $this->adapter->canCapture();
    }

    /**
     * @inheritDoc
     */
    public function canCapturePartial()
    {
        return $this->adapter->canCapturePartial();
    }

    /**
     * @inheritDoc
     */
    public function canCaptureOnce()
    {
        return $this->adapter->canCaptureOnce();
    }

    /**
     * @inheritDoc
     */
    public function canRefund()
    {
        return $this->adapter->canRefund();
    }

    /**
     * @inheritDoc
     */
    public function canRefundPartialPerInvoice()
    {
        return $this->adapter->canRefundPartialPerInvoice();
    }

    /**
     * @inheritDoc
     */
    public function canVoid()
    {
        return $this->adapter->canVoid();
    }

    /**
     * @inheritDoc
     */
    public function canUseInternal()
    {
        return $this->adapter->canUseInternal();
    }

    /**
     * @inheritDoc
     */
    public function canUseCheckout()
    {
        return $this->adapter->canUseCheckout();
    }

    /**
     * @inheritDoc
     */
    public function canEdit()
    {
        return $this->adapter->canEdit();
    }

    /**
     * @inheritDoc
     */
    public function canFetchTransactionInfo()
    {
        return $this->adapter->canFetchTransactionInfo();
    }

    /**
     * @inheritDoc
     */
    public function fetchTransactionInfo(InfoInterface $payment, $transactionId)
    {
        return $this->adapter->fetchTransactionInfo($payment, $transactionId);
    }

    /**
     * @inheritDoc
     */
    public function isGateway()
    {
        return $this->adapter->isGateway();
    }

    /**
     * @inheritDoc
     */
    public function isOffline()
    {
        return $this->adapter->isOffline();
    }

    /**
     * @inheritDoc
     */
    public function isInitializeNeeded()
    {
        return $this->adapter->isInitializeNeeded();
    }

    /**
     * @inheritDoc
     */
    public function canUseForCountry($country)
    {
        return $this->adapter->canUseForCountry($country);
    }

    /**
     * @inheritDoc
     */
    public function canUseForCurrency($currencyCode)
    {
        return $this->adapter->canUseForCurrency($currencyCode);
    }

    /**
     * @inheritDoc
     */
    public function getInfoBlockType()
    {
        return $this->adapter->getInfoBlockType();
    }

    /**
     * @inheritDoc
     */
    public function getInfoInstance()
    {
        return $this->adapter->getInfoInstance();
    }

    /**
     * @inheritDoc
     */
    public function setInfoInstance(InfoInterface $info)
    {
        $this->adapter->setInfoInstance($info);
    }

    /**
     * @inheritDoc
     */
    public function validate()
    {
        $this->adapter->validate();
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function order(InfoInterface $payment, $amount)
    {
        $this->adapter->order($payment, $amount);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function authorize(InfoInterface $payment, $amount)
    {
        $this->adapter->authorize($payment, $amount);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function capture(InfoInterface $payment, $amount)
    {
        $this->adapter->capture($payment, $amount);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function refund(InfoInterface $payment, $amount)
    {
        $this->adapter->refund($payment, $amount);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function cancel(InfoInterface $payment)
    {
        $this->adapter->cancel($payment);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function void(InfoInterface $payment)
    {
        $this->adapter->void($payment);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function canReviewPayment()
    {
        return $this->adapter->canReviewPayment();
    }

    /**
     * @inheritDoc
     */
    public function acceptPayment(InfoInterface $payment)
    {
        $this->adapter->acceptPayment($payment);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function denyPayment(InfoInterface $payment)
    {
        $this->adapter->denyPayment($payment);
        return $this;
    }

    /**
     * @inheritDoc
     */
    public function getConfigData($field, $storeId = null)
    {
        return $this->adapter->getConfigData($field, $storeId);
    }

    /**
     * @inheritDoc
     */
    public function assignData(DataObject $data)
    {
        $this->adapter->assignData($data);
        return $this;
    }

    /**
     * @inheritDoc
     * @throws NoSuchEntityException
     */
    public function isAvailable(CartInterface $quote = null)
    {
        $isAvailable = $this->adapter->isAvailable($quote);

        if ($quote !== null) {
            $store = $this->storeManager->getStore($quote->getStoreId());

            $websiteId = $store->getWebsiteId();

            return $isAvailable &&
                $this->config->getPartnerCurrency($websiteId) === $quote->getCurrency()->getQuoteCurrencyCode();
        }

        return $isAvailable;
    }

    /**
     * @inheritDoc
     * @throws NoSuchEntityException
     */
    public function isActive($storeId = null)
    {
        $isActive = $this->config->isActive($storeId);

        $store = $this->storeManager->getStore($storeId);

        $websiteId = $store->getWebsiteId();

        $partnerStatus = $this->config->getPartnerStatus($websiteId);

        return $isActive && $partnerStatus == ActivationRequestInterface::STATUS_ACTIVATED;
    }

    /**
     * @inheritDoc
     */
    public function initialize($paymentAction, $stateObject)
    {
        return $this->adapter->initialize($paymentAction, $stateObject);
    }

    /**
     * @inheritDoc
     */
    public function getConfigPaymentAction()
    {
        return $this->adapter->getConfigPaymentAction();
    }
}
