<?php

declare(strict_types=1);

namespace Evidente\Aircash\Rest;

use Evidente\Aircash\Api\Data\Transaction\ConfirmationResponseInterface;
use Evidente\Aircash\Api\Factory\Transaction\ConfirmationResultFactoryInterface;
use Evidente\Aircash\Api\Rest\TransactionConfirmationHandlerInterface;
use Evidente\Aircash\Api\TransactionProcessorInterface;
use Evidente\Aircash\Data\Transaction\ConfirmationResponse;
use Evidente\Aircash\Exception\InvalidInputException;
use Evidente\Aircash\Exception\InvalidSignatureException;
use Evidente\Aircash\Exception\TransactionProcessorException;
use Magento\Framework\Webapi\Exception as WebApiException;

/**
 * @SuppressWarnings(Long)
 */
class TransactionConfirmationHandler implements TransactionConfirmationHandlerInterface
{
    /**
     * @var ConfirmationResultFactoryInterface
     */
    private $confirmationResultFactory;

    /**
     * @var TransactionProcessorInterface
     */
    private $transactionProcessor;

    public function __construct(
        ConfirmationResultFactoryInterface $confirmationResultFactory,
        TransactionProcessorInterface $transactionProcessor
    ) {
        $this->confirmationResultFactory = $confirmationResultFactory;
        $this->transactionProcessor = $transactionProcessor;
    }

    /**
     * @inheritDoc
     */
    public function execute(): ConfirmationResponseInterface
    {
        try {
            $result = $this->confirmationResultFactory->createFromRequest();
        } catch (InvalidInputException $exception) {
            throw new WebApiException(
                __('Invalid input')
            );
        } catch (InvalidSignatureException $exception) {
            throw new WebApiException(
                __('Invalid signature')
            );
        }

        try {
            $this->transactionProcessor->process($result);
        } catch (TransactionProcessorException $exception) {
            throw new WebApiException(
                __($exception->getMessage())
            );
        }

        return new ConfirmationResponse('OK');
    }
}
