<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Block\Adminhtml;

use Magento\Backend\Block\AbstractBlock;
use Magento\Backend\Model\Session;
use Magento\Framework\App\Cache\StateInterface;
use Magento\Framework\App\CacheInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\State;
use Magento\Framework\AuthorizationInterface;
use Magento\Framework\Cache\LockGuardedCacheLoader;
use Magento\Framework\Code\NameBuilder;
use Magento\Framework\Data\Form\FormKey;
use Magento\Framework\Escaper;
use Magento\Framework\Event\ManagerInterface;
use Magento\Framework\Filesystem;
use Magento\Framework\Filter\FilterManager;
use Magento\Framework\Math\Random;
use Magento\Framework\Session\Generic;
use Magento\Framework\Session\SidResolverInterface;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Asset\Repository;
use Magento\Framework\View\ConfigInterface;
use Magento\Framework\View\DesignInterface;
use Magento\Framework\View\Element\Template\File\Resolver;
use Magento\Framework\View\Element\Template\File\Validator;
use Magento\Framework\View\LayoutInterface;
use Magento\Framework\View\Page\Config;
use Magento\Framework\View\TemplateEnginePool;
use Magento\Store\Model\StoreManagerInterface;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Magento\Backend\Block\Template\Context;
use Psr\Log\LoggerInterface;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
abstract class AbstractBlockTest extends TestCase
{
    /**
     * @var RequestInterface|MockObject
     */
    protected $request;

    /**
     * @var LayoutInterface|MockObject
     */
    protected $layout;

    /**
     * @var ManagerInterface|MockObject
     */
    protected $eventManager;

    /**
     * @var UrlInterface|MockObject
     */
    protected $urlBuilder;

    /**
     * @var CacheInterface|MockObject
     */
    protected $cache;

    /**
     * @var DesignInterface|MockObject
     */
    protected $design;

    /**
     * @var Generic|MockObject
     */
    protected $session;

    /**
     * @var SidResolverInterface|MockObject
     */
    protected $sidResolver;

    /**
     * @var ScopeConfigInterface|MockObject
     */
    protected $scopeConfig;

    /**
     * @var Repository|MockObject
     */
    protected $assetRepo;

    /**
     * @var ConfigInterface|MockObject
     */
    protected $viewConfig;

    /**
     * @var StateInterface|MockObject
     */
    protected $cacheState;

    /**
     * @var LoggerInterface|MockObject
     */
    protected $logger;

    /**
     * @var Escaper
     */
    protected $escaper;

    /**
     * @var FilterManager|MockObject
     */
    protected $filterManager;

    /**
     * @var TimezoneInterface|MockObject
     */
    protected $localeDate;

    /**
     * @var \Magento\Framework\Translate\Inline\StateInterface|MockObject
     */
    protected $inlineTranslation;

    /**
     * @var Filesystem|MockObject
     */
    protected $fileSystem;

    /**
     * @var \Magento\Framework\View\FileSystem|MockObject
     */
    protected $viewFileSystem;

    /**
     * @var TemplateEnginePool|MockObject
     */
    protected $enginePool;

    /**
     * @var State|MockObject
     */
    protected $appState;

    /**
     * @var StoreManagerInterface|MockObject
     */
    protected $storeManager;

    /**
     * @var Config|MockObject
     */
    protected $pageConfig;

    /**
     * @var Resolver|MockObject
     */
    protected $resolver;

    /**
     * @var Validator|MockObject
     */
    protected $validator;

    /**
     * @var AuthorizationInterface|MockObject
     */
    protected $authorization;

    /**
     * @var Session|MockObject
     */
    protected $backendSession;

    /**
     * @var Random|MockObject
     */
    protected $mathRandom;

    /**
     * @var FormKey|MockObject
     */
    protected $formKey;

    /**
     * @var NameBuilder|MockObject
     */
    protected $nameBuilder;

    /**
     * @var null|LockGuardedCacheLoader
     */
    protected $lockQuery = null;

    /**
     * @var AbstractBlock|MockObject
     */
    protected $block;

    /**
     * @var Context
     */
    protected $context;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->request = $this->createMock(Http::class);

        $this->block = $this->createMock(AbstractBlock::class);
        $this->layout = $this->createMock(LayoutInterface::class);
        $this->eventManager = $this->createMock(ManagerInterface::class);
        $this->urlBuilder = $this->createMock(UrlInterface::class);
        $this->cache = $this->createMock(CacheInterface::class);
        $this->design = $this->createMock(DesignInterface::class);
        $this->session = $this->createMock(Generic::class);
        $this->sidResolver = $this->createMock(SidResolverInterface::class);
        $this->scopeConfig = $this->createMock(ScopeConfigInterface::class);
        $this->assetRepo = $this->createMock(Repository::class);
        $this->viewConfig = $this->createMock(ConfigInterface::class);
        $this->cacheState = $this->createMock(StateInterface::class);
        $this->logger = $this->createMock(LoggerInterface::class);
        $this->escaper = new Escaper();
        $this->filterManager = $this->createMock(FilterManager::class);
        $this->localeDate = $this->createMock(TimezoneInterface::class);
        $this->inlineTranslation = $this->createMock(\Magento\Framework\Translate\Inline\StateInterface::class);
        $this->fileSystem = $this->createMock(Filesystem::class);
        $this->viewFileSystem = $this->createMock(\Magento\Framework\View\FileSystem::class);
        $this->enginePool = $this->createMock(TemplateEnginePool::class);
        $this->appState = $this->createMock(State::class);
        $this->storeManager = $this->createMock(StoreManagerInterface::class);
        $this->pageConfig = $this->createMock(Config::class);
        $this->resolver = $this->createMock(Resolver::class);
        $this->validator = $this->createMock(Validator::class);
        $this->authorization = $this->createMock(AuthorizationInterface::class);
        $this->backendSession = $this->createMock(Session::class);
        $this->mathRandom = $this->createMock(Random::class);
        $this->formKey = $this->createMock(FormKey::class);
        $this->nameBuilder = $this->createMock(NameBuilder::class);

        $this->context = new Context(
            $this->request,
            $this->layout,
            $this->eventManager,
            $this->urlBuilder,
            $this->cache,
            $this->design,
            $this->session,
            $this->sidResolver,
            $this->scopeConfig,
            $this->assetRepo,
            $this->viewConfig,
            $this->cacheState,
            $this->logger,
            $this->escaper,
            $this->filterManager,
            $this->localeDate,
            $this->inlineTranslation,
            $this->fileSystem,
            $this->viewFileSystem,
            $this->enginePool,
            $this->appState,
            $this->storeManager,
            $this->pageConfig,
            $this->resolver,
            $this->validator,
            $this->authorization,
            $this->backendSession,
            $this->mathRandom,
            $this->formKey,
            $this->nameBuilder,
            $this->lockQuery
        );
    }
}
