<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Block\Adminhtml;

use Evidente\Aircash\Block\Adminhtml\ActivationBlock;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\Website;
use PHPUnit\Framework\MockObject\MockObject;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class ActivationBlockTest extends AbstractBlockTest
{
    /**
     * @var ActivationBlock
     */
    private $subject;

    /**
     * @var Website|MockObject
     */
    private $website;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        parent::setUp();

        $this->website = $this->createMock(Website::class);

        $this->subject = new ActivationBlock($this->context);
    }

    /**
     * @throws NoSuchEntityException
     * @throws LocalizedException
     */
    public function testGetStoreName()
    {
        // given
        $expectedStoreName = 'store name';

        $this
            ->request
            ->method('getParam')
            ->with('website')
            ->willReturn(1);

        $this
            ->website
            ->expects($this->once())
            ->method('getName')
            ->willReturn($expectedStoreName);

        $this
            ->storeManager
            ->expects($this->once())
            ->method('getWebsite')
            ->with(1)
            ->willReturn($this->website);

        // when
        $result = $this->subject->getStoreName();

        // then
        $this->assertSame($expectedStoreName, $result);
    }

    public function testGetStoreEmail()
    {
        // given
        $expectedEmail = 'email';

        $this
            ->request
            ->method('getParam')
            ->with('website')
            ->willReturn(1);

        $this
            ->scopeConfig
            ->expects($this->once())
            ->method('getValue')
            ->with(
                'trans_email/ident_sales/email',
                ScopeInterface::SCOPE_WEBSITE,
                1
            )
            ->willReturn($expectedEmail);

        // when
        $result = $this->subject->getStoreEmail();

        // then
        $this->assertSame($expectedEmail, $result);
    }

    public function testGetStorePhone()
    {
        // given
        $expectedPhone = 'phone';

        $this
            ->request
            ->method('getParam')
            ->with('website')
            ->willReturn(1);

        $this
            ->scopeConfig
            ->expects($this->once())
            ->method('getValue')
            ->with(
                'general/store_information/phone',
                ScopeInterface::SCOPE_WEBSITE,
                1
            )
            ->willReturn($expectedPhone);

        // when
        $result = $this->subject->getStorePhone();

        // then
        $this->assertSame($expectedPhone, $result);
    }
}
