<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Block\Adminhtml\System\Config\Form;

use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Evidente\Aircash\Block\Adminhtml\System\Config\Form\ActionButtonBlock;
use Evidente\Aircash\Model\Config\PartnerConfig;
use Evidente\Aircash\Test\Unit\Block\Adminhtml\AbstractBlockTest;
use Magento\Backend\Block\Widget\Button;
use PHPUnit\Framework\MockObject\MockObject;

class ActionButtonBlockTest extends AbstractBlockTest
{
    /**
     * @var PartnerConfig|MockObject
     */
    private $partnerConfig;

    /**
     * @var Button|MockObject
     */
    private $button;

    /**
     * @var ActionButtonBlock
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();

        $this->button = $this->createMock(Button::class);
        $this->button->method('setData')->willReturn($this->button);

        $this
            ->layout
            ->method('createBlock')
            ->with(Button::class)
            ->willReturn($this->button);

        $this->partnerConfig = $this->createMock(PartnerConfig::class);
        $this->subject = new ActionButtonBlock($this->context, $this->partnerConfig);
    }

    public function testGetActivateButton()
    {
        // given
        $this
            ->partnerConfig
            ->expects($this->once())
            ->method('getPartnerStatus')
            ->willReturn(ActivationRequestInterface::STATUS_NOT_ACTIVATED);

        $this
            ->button
            ->expects($this->once())
            ->method('setData')
            ->with(
                [
                    'id' => 'aircash-partner-action-button-prod',
                    'label' => __('Activate'),
                ]
            );

        // when
        $result = $this->subject->getButton();

        // then
        $this->assertInstanceOf(Button::class, $result);
    }

    public function testGetCheckButton()
    {
        // given
        $this
            ->partnerConfig
            ->expects($this->once())
            ->method('getPartnerStatus')
            ->willReturn(ActivationRequestInterface::STATUS_PENDING);

        $this
            ->button
            ->expects($this->once())
            ->method('setData')
            ->with(
                [
                    'id' => 'aircash-partner-action-button-prod',
                    'label' => __('Check Activation Status'),
                ]
            );

        // when
        $result = $this->subject->getButton();

        // then
        $this->assertInstanceOf(Button::class, $result);
    }

    /**
     * @dataProvider getStatuses
     */
    public function testGetNoButtonOnOtherStatuses(int $status)
    {
        // given
        $this
            ->partnerConfig
            ->expects($this->once())
            ->method('getPartnerStatus')
            ->willReturn($status);

        $this
            ->button
            ->expects($this->never())
            ->method('setData');

        // when
        $result = $this->subject->getButton();

        // then
        $this->assertNull($result);
    }

    public static function getStatuses()
    {
        return [
            [ActivationRequestInterface::STATUS_REJECTED],
        ];
    }
}
