<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Block\Adminhtml\System\Config\Form;

use Evidente\Aircash\Block\Adminhtml\System\Config\Form\FieldContextTrait;
use Evidente\Aircash\Block\Adminhtml\System\Config\Form\PartnerIdField;
use Evidente\Aircash\Model\Config\PartnerConfig;
use Evidente\Aircash\Test\Unit\Block\Adminhtml\AbstractBlockTest;
use Magento\Framework\Data\Form\Element\Text;
use PHPUnit\Framework\MockObject\MockObject;

class PartnerIdFieldTest extends AbstractBlockTest
{
    use FieldContextTrait;

    /**
     * @var Text|MockObject
     */
    private $element;

    /**
     * @var PartnerConfig|MockObject
     */
    private $partnerConfig;

    /**
     * @var PartnerIdField
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();
        $this->element = $this->createMock(Text::class);
        $this->partnerConfig = $this->createMock(PartnerConfig::class);
        $this->subject = new PartnerIdField($this->context, $this->partnerConfig);
    }

    public function testRender()
    {
        // given
        $expectedPartnerId = 'partner_id';
        $expectedHtml = $this->getFakeInput($expectedPartnerId);
        $expectedWebsiteId = 1;
        $expectedElementData = '/test';

        $this->element->method('getDataByPath')->with('field_config/path')->willReturn($expectedElementData);
        $this->request->method('getParam')->with('website')->willReturn($expectedWebsiteId);
        $this->partnerConfig->expects($this->once())->method('getPartnerId')->willReturn($expectedPartnerId);

        // when
        $result = $this->subject->render($this->element);

        // then
        $this->assertNotFalse(strpos($result, $expectedHtml));
    }
}
