<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Controller;

use Magento\Framework\App\Action\Context;
use Magento\Framework\App\ActionFlag;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\Response\RedirectInterface;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\App\ViewInterface;
use Magento\Framework\Controller\Result\RedirectFactory;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Event\ManagerInterface;
use Magento\Framework\ObjectManagerInterface;
use Magento\Framework\UrlInterface;
use Magento\Store\App\Response\Redirect;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
abstract class AbstractControllerTest extends TestCase
{
    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * @var ResponseInterface
     */
    protected $response;

    /**
     * @var ObjectManagerInterface
     */
    protected $objectManager;

    /**
     * @var ManagerInterface
     */
    protected $eventManager;

    /**
     * @var UrlInterface
     */
    protected $url;

    /**
     * @var RedirectInterface
     */
    protected $redirect;

    /**
     * @var ActionFlag
     */
    protected $actionFlag;

    /**
     * @var ViewInterface
     */
    protected $view;

    /**
     * @var \Magento\Framework\Message\ManagerInterface
     */
    protected $messageManager;

    /**
     * @var RedirectFactory
     */
    protected $resultRedirectFactory;

    /**
     * @var \Magento\Framework\Controller\Result\Redirect
     */
    protected $resultRedirect;

    /**
     * @var ResultFactory
     */
    protected $resultFactory;

    /**
     * @var Context
     */
    protected $context;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->request = $this->createMock(Http::class);

        $this->response = $this
            ->getMockBuilder(\Magento\Framework\App\Response\Http::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods(['setRedirect'])
            ->getMock();

        $this->objectManager = $this->createMock(ObjectManagerInterface::class);
        $this->eventManager = $this->createMock(ManagerInterface::class);
        $this->url = $this->createMock(UrlInterface::class);

        $this->redirect = $this
            ->getMockBuilder(Redirect::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods(['setRedirect', 'getRefererUrl'])
            ->getMock();

        $this->actionFlag = $this->createMock(ActionFlag::class);
        $this->view = $this->createMock(ViewInterface::class);
        $this->messageManager = $this->createMock(\Magento\Framework\Message\ManagerInterface::class);

        $this->resultRedirectFactory = $this->createMock(RedirectFactory::class);
        $this->resultRedirect = $this->createMock(\Magento\Framework\Controller\Result\Redirect::class);

        $this->resultRedirectFactory->method('create')->willReturn($this->resultRedirect);

        $this->resultFactory = $this->createMock(ResultFactory::class);

        $this->context = new Context(
            $this->request,
            $this->response,
            $this->objectManager,
            $this->eventManager,
            $this->url,
            $this->redirect,
            $this->actionFlag,
            $this->view,
            $this->messageManager,
            $this->resultRedirectFactory,
            $this->resultFactory
        );
    }
}
