<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Controller\Adminhtml\Activation;

use Magento\Backend\App\Action\Context;
use Magento\Backend\Helper\Data;
use Magento\Backend\Model\Auth;
use Magento\Backend\Model\Session;
use Magento\Backend\Model\View\Result\RedirectFactory;
use Magento\Framework\App\ActionFlag;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\Response\RedirectInterface;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\App\ViewInterface;
use Magento\Framework\AuthorizationInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Data\Form\FormKey\Validator;
use Magento\Framework\Event\ManagerInterface;
use Magento\Framework\Locale\ResolverInterface;
use Magento\Framework\ObjectManagerInterface;
use Magento\Framework\UrlInterface;
use Magento\Store\App\Response\Redirect;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
abstract class AbstractControllerTest extends TestCase
{
    /**
     * @var RequestInterface|MockObject
     */
    protected $request;

    /**
     * @var ResponseInterface|MockObject
     */
    protected $response;

    /**
     * @var ObjectManagerInterface|MockObject
     */
    protected $objectManager;

    /**
     * @var ManagerInterface|MockObject
     */
    protected $eventManager;

    /**
     * @var UrlInterface|MockObject
     */
    protected $url;

    /**
     * @var RedirectInterface|MockObject
     */
    protected $redirect;

    /**
     * @var ActionFlag|MockObject
     */
    protected $actionFlag;

    /**
     * @var ViewInterface|MockObject
     */
    protected $view;

    /**
     * @var \Magento\Framework\Message\ManagerInterface|MockObject
     */
    protected $messageManager;

    /**
     * @var RedirectFactory|MockObject
     */
    protected $resultRedirectFactory;

    /**
     * @var ResultFactory|MockObject
     */
    protected $resultFactory;

    /**
     * @var Session|MockObject
     */
    protected $session;

    /**
     * @var AuthorizationInterface|MockObject
     */
    protected $authorization;

    /**
     * @var Auth|MockObject
     */
    protected $auth;

    /**
     * @var Data|MockObject
     */
    protected $helper;

    /**
     * @var \Magento\Backend\Model\UrlInterface|MockObject
     */
    protected $backendUrl;

    /**
     * @var Validator|MockObject
     */
    protected $formKeyValidator;

    /**
     * @var ResolverInterface|MockObject
     */
    protected $localeResolver;

    protected $canUseBaseUrl = false;

    /**
     * @var Context|MockObject
     */
    protected $context;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->request = $this->createMock(Http::class);

        $this->response = $this
            ->getMockBuilder(\Magento\Framework\App\Response\Http::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods(['setRedirect'])
            ->getMock();

        $this->objectManager = $this->createMock(ObjectManagerInterface::class);
        $this->eventManager = $this->createMock(ManagerInterface::class);
        $this->url = $this->createMock(UrlInterface::class);

        $this->redirect = $this
            ->getMockBuilder(Redirect::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods(['setRedirect', 'getRefererUrl'])
            ->getMock();

        $this->actionFlag = $this->createMock(ActionFlag::class);
        $this->view = $this->createMock(ViewInterface::class);
        $this->messageManager = $this->createMock(\Magento\Framework\Message\ManagerInterface::class);
        $this->resultRedirectFactory = $this->createMock(RedirectFactory::class);
        $this->resultFactory = $this->createMock(ResultFactory::class);
        $this->session = $this->createMock(Session::class);
        $this->authorization = $this->createMock(AuthorizationInterface::class);
        $this->auth = $this->createMock(Auth::class);
        $this->helper = $this->createMock(Data::class);
        $this->backendUrl = $this->createMock(\Magento\Backend\Model\UrlInterface::class);
        $this->formKeyValidator = $this->createMock(Validator::class);
        $this->localeResolver = $this->createMock(ResolverInterface::class);

        $this->context = new Context(
            $this->request,
            $this->response,
            $this->objectManager,
            $this->eventManager,
            $this->url,
            $this->redirect,
            $this->actionFlag,
            $this->view,
            $this->messageManager,
            $this->resultRedirectFactory,
            $this->resultFactory,
            $this->session,
            $this->authorization,
            $this->auth,
            $this->helper,
            $this->backendUrl,
            $this->formKeyValidator,
            $this->localeResolver,
            $this->canUseBaseUrl
        );
    }
}
