<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Controller\Adminhtml\Activation;

use Evidente\Aircash\Controller\Adminhtml\Activation\Status;
use Evidente\Aircash\Facade\PartnerCheckFacade;
use Magento\Framework\Exception\NotFoundException;
use PHPUnit\Framework\MockObject\MockObject;

class StatusTest extends AbstractControllerTest
{
    /**
     * @var PartnerCheckFacade|MockObject
     */
    private $partnerCheckFacade;

    /**
     * @var Status
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();
        $this->partnerCheckFacade = $this->createMock(PartnerCheckFacade::class);
        $this->subject = new Status($this->context, $this->partnerCheckFacade);
    }

    /**
     * @throws NotFoundException
     */
    public function testExecute()
    {
        // given
        $expectedRedirectUrl = '/';
        $expectedMessage = 'message';
        $expectedErrorMessage = 'error';

        $this
            ->helper
            ->expects($this->once())
            ->method('getUrl')
            ->willReturn($expectedRedirectUrl);

        $this
            ->partnerCheckFacade
            ->expects($this->once())
            ->method('check')
            ->willReturn([$expectedMessage, $expectedErrorMessage]);

        $this
            ->messageManager
            ->expects($this->once())
            ->method('addErrorMessage')
            ->with($expectedErrorMessage);

        $this
            ->messageManager
            ->expects($this->once())
            ->method('addSuccessMessage')
            ->with($expectedMessage);

        $this
            ->redirect
            ->expects($this->once())
            ->method('getRefererUrl')
            ->willReturn($expectedRedirectUrl);

        $this
            ->response
            ->expects($this->once())
            ->method('setRedirect')
            ->with($expectedRedirectUrl, 302);

        // when, then
        $this->subject->execute();
    }
}
