<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Controller\Checkout;

use Evidente\Aircash\Controller\Checkout\Payment;
use Evidente\Aircash\Test\Unit\Controller\AbstractControllerTest;
use Magento\Backend\Model\View\Result\Page;
use Magento\Checkout\Model\SessionFactory;
use Magento\Checkout\Model\Session;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\View\Page\Config;
use Magento\Framework\View\Page\Title;
use PHPUnit\Framework\MockObject\MockObject;

/**
 * @SuppressWarnings(PHPMD)
 */
class PaymentTest extends AbstractControllerTest
{
    /**
     * @var Page|MockObject
     */
    private $page;

    /**
     * @var Config|MockObject
     */
    private $config;

    /**
     * @var Title|MockObject
     */
    private $title;

    /**
     * @var SessionFactory|MockObject
     */
    private $sessionFactory;

    /**
     * @var Session|MockObject
     */
    private $session;

    /**
     * @var Payment
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();

        $this->page = $this->createMock(Page::class);
        $this->config = $this->createMock(Config::class);
        $this->title = $this->createMock(Title::class);

        $this->page->method('getConfig')->willReturn($this->config);
        $this->config->method('getTitle')->willReturn($this->title);

        $this->sessionFactory = $this->createMock(SessionFactory::class);
        $this->session = $this
            ->getMockBuilder(Session::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods(['getLastOrderId'])
            ->getMock();

        $this->sessionFactory->method('create')->willReturn($this->session);
        $this->subject = new Payment($this->context, $this->sessionFactory);
    }

    /**
     * @throws NotFoundException
     */
    public function testExecuteShouldRedirectBecauseOfNoLastOrderId()
    {
        // given
        $this
            ->session
            ->expects($this->once())
            ->method('getLastOrderId')
            ->willReturn(null);

        $this
            ->resultRedirect
            ->expects($this->once())
            ->method('setPath')
            ->with('checkout/cart');

        // when, then
        $this->subject->execute();
    }

    /**
     * @throws NotFoundException
     */
    public function testExecute()
    {
        // given
        $this
            ->session
            ->expects($this->once())
            ->method('getLastOrderId')
            ->willReturn(1);

        $this
            ->resultFactory
            ->expects($this->once())
            ->method('create')
            ->with(ResultFactory::TYPE_PAGE)
            ->willReturn($this->page);

        // when, then
        $this->subject->execute();
    }
}
