<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Data\Partner;

use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Data\Partner\ActivationRequest;
use PHPUnit\Framework\TestCase;

/**
 * @SuppressWarnings(PHPMD)
 */
class ActivationRequestTest extends TestCase
{
    /**
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::__construct
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getPublicKey
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getPhoneNumber
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getContactEmail
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getConfirmTransactionURL
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getCurrencyID
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getPartnerName
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getPartnerID
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::getPlatformID
     * @covers \Evidente\Aircash\Data\Partner\ActivationRequest::toArray
     */
    public function testData()
    {
        // given
        $expectedPublicKey = 'public_key';
        $expectedPhoneNumber = '5554444';
        $expectedContactEmail = 'email@example.com';
        $expectedConfirmTransactionURL = 'example.com';
        $expectedCurrencyID = CodeRequestInterface::CURRENCY_MAPPING[CodeRequestInterface::CURRENCY_EUR];
        $expectedPartnerName = 'partner_name';
        $expectedPartnerID = 'partner_id';
        $expectedPlatformID = 'platform_id';
        $expectedWebsiteId = 1;
        $expectedNote = null;

        $expectedArray = [
            'PlatformID' => $expectedPlatformID,
            'PartnerID' => $expectedPartnerID,
            'PartnerName' => $expectedPartnerName,
            'PublicKey' => $expectedPublicKey,
            'CurrencyID' => $expectedCurrencyID,
            'ConfirmTransactionURL' => $expectedConfirmTransactionURL,
            'ContactEmail' => $expectedContactEmail,
            'PhoneNumber' => $expectedPhoneNumber,
            'Note' => $expectedNote,
        ];

        // when
        $model = new ActivationRequest(
            $expectedPlatformID,
            $expectedPartnerID,
            $expectedPartnerName,
            $expectedPublicKey,
            $expectedCurrencyID,
            $expectedConfirmTransactionURL,
            $expectedContactEmail,
            $expectedPhoneNumber,
            $expectedWebsiteId
        );

        // then
        $this->assertSame($expectedPlatformID, $model->getPlatformID());
        $this->assertSame($expectedPartnerID, $model->getPartnerID());
        $this->assertSame($expectedPartnerName, $model->getPartnerName());
        $this->assertSame($expectedPublicKey, $model->getPublicKey());
        $this->assertSame($expectedCurrencyID, $model->getCurrencyID());
        $this->assertSame($expectedConfirmTransactionURL, $model->getConfirmTransactionURL());
        $this->assertSame($expectedContactEmail, $model->getContactEmail());
        $this->assertSame($expectedPhoneNumber, $model->getPhoneNumber());
        $this->assertSame($expectedWebsiteId, $model->getWebsiteId());
        $this->assertSame($expectedNote, $model->getNote());

        $this->assertSame($expectedArray, $model->toArray());
    }
}
