<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Data\Transaction;

use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Data\Transaction\CodeRequest;
use PHPUnit\Framework\TestCase;

/**
 * @SuppressWarnings(PHPMD)
 */
class CodeRequestTest extends TestCase
{
    /**
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getAmount
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getPartnerTransactionID
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::toArray
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getLocationID
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getDescription
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getCurrencyID
     * @covers \Evidente\Aircash\Data\Transaction\CodeRequest::getPartnerID
     */
    public function testData()
    {
        // given
        $expectedPartnerId = 'partner_id';
        $expectedAmount = 5.00;
        $expectedCurrency = CodeRequestInterface::CURRENCY_MAPPING[CodeRequestInterface::CURRENCY_EUR];
        $expectedPartnerTransactionId = 'transaction_id';
        $expectedDescription = 'description';
        $expectedLocationId = 'location_id';
        $expectedWebsiteId = 1;
        $expectedValidForPeriod = 5;

        $expectedArray = [
            'PartnerID' => $expectedPartnerId,
            'Amount' => $expectedAmount,
            'CurrencyID' => $expectedCurrency,
            'PartnerTransactionID' => $expectedPartnerTransactionId,
            'Description' => $expectedDescription,
            'LocationID' => $expectedLocationId,
        ];

        // when
        $model = new CodeRequest(
            $expectedPartnerId,
            $expectedAmount,
            $expectedCurrency,
            $expectedPartnerTransactionId,
            $expectedDescription,
            $expectedLocationId,
            $expectedWebsiteId
        );

        // then
        $this->assertSame($expectedPartnerId, $model->getPartnerID());
        $this->assertSame($expectedAmount, $model->getAmount());
        $this->assertSame($expectedCurrency, $model->getCurrencyID());
        $this->assertSame($expectedPartnerTransactionId, $model->getPartnerTransactionID());
        $this->assertSame($expectedDescription, $model->getDescription());
        $this->assertSame($expectedLocationId, $model->getLocationID());
        $this->assertSame($expectedWebsiteId, $model->getWebsiteId());
        $this->assertSame($expectedValidForPeriod, $model->getValidForPeriod());

        $this->assertSame($expectedArray, $model->toArray());
    }
}
