<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Factory;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Factory\HttpClientFactoryInterface;
use Evidente\Aircash\Factory\HttpClientFactory;
use GuzzleHttp\Psr7\Uri;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class HttpClientFactoryTest extends TestCase
{
    /**
     * @var ConfigInterface|MockObject
     */
    private $config;

    /**
     * @var HttpClientFactoryInterface
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->config = $this->createMock(ConfigInterface::class);
        $this->subject = new HttpClientFactory($this->config);
    }

    /**
     * @dataProvider configDataProvider
     */
    public function testCreate(bool $testMode, bool $developerMode, string $baseUri)
    {
        // given
        $this->config->method('isTestMode')->willReturn($testMode);
        $this->config->method('isDeveloperMode')->willReturn($developerMode);

        // when
        $client = $this->subject->create();

        // then
        /**
         * @var Uri $config
         */
        $config = $client->getConfig('base_uri');

        $this->assertInstanceOf(Uri::class, $config);

        $expectedUrl = $config->getScheme() . '://' . $config->getHost() . $config->getPath();

        $this->assertSame($baseUri, $expectedUrl);
    }

    public function configDataProvider(): array
    {
        return [
            [true, false, ConfigInterface::TEST_BASE_URL],
            [false, false, ConfigInterface::PROD_BASE_URL],
            [true, true, ConfigInterface::DEV_BASE_URL]
        ];
    }
}
