<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Factory;

use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Api\SignatureStringFactoryInterface;
use Evidente\Aircash\Factory\SignatureStringFactory;
use PHPUnit\Framework\TestCase;

/**
 * @SuppressWarnings(PHPMD)
 */
class SignatureStringFactoryTest extends TestCase
{
    /**
     * @var SignatureStringFactoryInterface
     */
    private $subject;

    protected function setUp(): void
    {
        $this->subject = new SignatureStringFactory();
    }

    public function testCreateFromArray()
    {
        $expectedCurrency = CodeRequestInterface::CURRENCY_MAPPING[CodeRequestInterface::CURRENCY_EUR];

        $inputs = [
            [
                [
                    'PartnerID' => 'partner_id',
                    'Amount' => 5.00,
                    'CurrencyID' => $expectedCurrency,
                    'PartnerTransactionID' => 'transaction_id',
                    'Description' => 'Order-transaction_id',
                    'LocationID' => 'location_id',
                ],
                'Amount=5&CurrencyID=' . $expectedCurrency
                . '&Description=Order-transaction_id&LocationID=location_id'
                . '&PartnerID=partner_id'
                . '&PartnerTransactionID=transaction_id'
            ],

            [
                [
                    'PartnerID' => 'partner_id',
                    'Amount' => 5.05,
                    'CurrencyID' => $expectedCurrency,
                    'PartnerTransactionID' => 'transaction_id',
                    'Description' => 'Order-transaction_id',
                    'LocationID' => 'location_id',
                ],
                'Amount=5.5&CurrencyID=' . $expectedCurrency
                . '&Description=Order-transaction_id&LocationID=location_id'
                . '&PartnerID=partner_id'
                . '&PartnerTransactionID=transaction_id'
            ],

            [
                [
                    'PartnerID' => 'partner_id',
                    'Amount' => 5.45,
                    'CurrencyID' => $expectedCurrency,
                    'PartnerTransactionID' => 'transaction_id',
                    'Description' => 'Order-transaction_id',
                    'LocationID' => 'location_id',
                ],
                'Amount=5.45&CurrencyID=' . $expectedCurrency
                . '&Description=Order-transaction_id&LocationID=location_id'
                . '&PartnerID=partner_id'
                . '&PartnerTransactionID=transaction_id'
            ],

            [
                [
                    'PartnerID' => 'partner_id',
                    'Amount' => 5,
                    'CurrencyID' => $expectedCurrency,
                    'PartnerTransactionID' => 'transaction_id',
                    'Description' => 'Order-transaction_id',
                    'LocationID' => 'location_id',
                ],
                'Amount=5&CurrencyID=' . $expectedCurrency
                . '&Description=Order-transaction_id&LocationID=location_id'
                . '&PartnerID=partner_id'
                . '&PartnerTransactionID=transaction_id'
            ]
        ];

        foreach ($inputs as $entry) {
            list($inputArray, $expectedResult) = $entry;

            $result = $this->subject->createFromArray($inputArray);

            $this->assertSame($expectedResult, $result);
        }
    }
}
