<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Factory\Transaction;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Factory\Transaction\CancellationRequestFactoryInterface;
use Evidente\Aircash\Exception\InvalidInputException;
use Evidente\Aircash\Factory\Transaction\CancellationRequestFactory;
use Magento\Sales\Model\Order;
use Magento\Store\Model\Store;
use Magento\Store\Model\StoreManagerInterface;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(Long)
 */
class CancellationRequestFactoryTest extends TestCase
{
    /**
     * @var Order|MockObject
     */
    private $order;

    /**
     * @var ConfigInterface|MockObject
     */
    private $config;

    /**
     * @var StoreManagerInterface|MockObject
     */
    private $storeManager;

    /**
     * @var Store|MockObject
     */
    private $store;

    /**
     * @var CancellationRequestFactoryInterface
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->order = $this->createMock(Order::class);
        $this->config = $this->createMock(ConfigInterface::class);

        $this->storeManager = $this->createMock(StoreManagerInterface::class);
        $this->store = $this->createMock(Store::class);

        $this->storeManager->method('getStore')->willReturn($this->store);

        $this->subject = new CancellationRequestFactory(
            $this->config,
            $this->storeManager
        );
    }

    /**
     * @throws InvalidInputException
     */
    public function testCreate()
    {
        // when
        $expectedPartnerId = 'partner_id';
        $expectedPartnerTransactionId = '000000001';
        $expectedWebsiteId = 1;

        $this->store->method('getWebsiteId')->willReturn($expectedWebsiteId);

        $this->order->method('getIncrementId')->willReturn($expectedPartnerTransactionId);
        $this->config->method('getPartnerID')->willReturn($expectedPartnerId);

        $request = $this->subject->createFromOrder($this->order);

        $this->assertSame($expectedPartnerId, $request->getPartnerID());
        $this->assertSame($expectedPartnerTransactionId, $request->getPartnerTransactionID());
    }

    /**
     * @throws InvalidInputException
     */
    public function testCreateWithPrefix()
    {
        // when
        $expectedPartnerId = 'partner_id';
        $expectedPartnerTransactionId = '000000001';
        $expectedWebsiteId = 1;

        $this->store->method('getWebsiteId')->willReturn($expectedWebsiteId);

        $this->order->method('getIncrementId')->willReturn($expectedPartnerTransactionId);
        $this->config->method('getPartnerID')->willReturn($expectedPartnerId);
        $this->config->method('getTransactionIdPrefix')->willReturn('prefix');

        $request = $this->subject->createFromOrder($this->order);

        $this->assertSame($expectedPartnerId, $request->getPartnerID());
        $this->assertSame('prefix' . $expectedPartnerTransactionId, $request->getPartnerTransactionID());
    }
}
