<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Gateway\Command;

use Evidente\Aircash\Api\AircashClientInterface;
use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Factory\Transaction\CancellationRequestFactoryInterface;
use Evidente\Aircash\Api\Factory\Transaction\RefundRequestFactoryInterface;
use Evidente\Aircash\Factory\Transaction\CancellationRequestFactory;
use Evidente\Aircash\Factory\Transaction\RefundRequestFactory;
use Magento\Sales\Model\Order;
use Magento\Store\Model\Store;
use Magento\Store\Model\StoreManagerInterface;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Psr\Log\LoggerInterface;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
abstract class AbstractCommandTest extends TestCase
{
    /**
     * @var StoreManagerInterface|MockObject
     */
    protected $storeManager;

    /**
     * @var Store|MockObject
     */
    protected $store;

    /**
     * @var ConfigInterface|MockObject
     */
    protected $config;

    /**
     * @var AircashClientInterface|MockObject
     */
    protected $aircashClient;

    /**
     * @var CancellationRequestFactoryInterface
     */
    protected $cancellationRequestFactory;

    /**
     * @var RefundRequestFactoryInterface
     */
    protected $refundRequestFactory;

    /**
     * @var LoggerInterface|MockObject
     */
    protected $logger;

    /**
     * @var Order\Payment|MockObject
     */
    protected $orderPayment;

    /**
     * @var Order|MockObject
     */
    protected $order;

    /**
     * @var Order\Creditmemo|MockObject
     */
    protected $creditMemo;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->storeManager = $this->createMock(StoreManagerInterface::class);
        $this->store = $this->createMock(Store::class);
        $this->config = $this->createMock(ConfigInterface::class);

        $this->cancellationRequestFactory = new CancellationRequestFactory($this->config, $this->storeManager);
        $this->refundRequestFactory = new RefundRequestFactory($this->config, $this->storeManager);

        $this->aircashClient = $this->createMock(AircashClientInterface::class);
        $this->logger = $this->createMock(LoggerInterface::class);
        $this->orderPayment = $this->createMock(Order\Payment::class);
        $this->order = $this->createMock(Order::class);
        $this->creditMemo = $this->createMock(Order\Creditmemo::class);

        $this->orderPayment->method('getOrder')->willReturn($this->order);
        $this->orderPayment->method('getCreditmemo')->willReturn($this->creditMemo);
    }
}
