<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Gateway\Command;

use Evidente\Aircash\Gateway\Command\Capture;
use Magento\Framework\DataObject;
use Magento\Payment\Gateway\Command\CommandException;

/**
 * @SuppressWarnings(PHPMD)
 */
class CaptureTest extends AbstractCommandTest
{
    /**
     * @var Capture
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();
        $this->subject = new Capture(
            $this->aircashClient,
            $this->cancellationRequestFactory,
            $this->refundRequestFactory,
            $this->logger
        );
    }

    /**
     * @throws CommandException
     */
    public function testExecute()
    {
        // given
        $expectedCommandSubject = [
            'payment' => new DataObject(['payment' => $this->orderPayment])
        ];

        $this->orderPayment->method('getCcTransId')->willReturn('transaction_id');

        $this
            ->orderPayment
            ->expects($this->once())
            ->method('setTransactionId')
            ->with('transaction_id');

        $this
            ->orderPayment
            ->expects($this->once())
            ->method('setIsTransactionClosed')
            ->with(1);

        // then
        $this->subject->execute($expectedCommandSubject);
    }

    /**
     * @throws CommandException
     */
    public function testExecuteShouldFailOnMissingTransactionId()
    {
        // given
        $expectedCommandSubject = [
            'payment' => new DataObject(['payment' => $this->orderPayment])
        ];

        $this
            ->order
            ->expects($this->never())
            ->method('setStatus');

        $this
            ->order
            ->expects($this->never())
            ->method('setState');

        $this
            ->orderPayment
            ->expects($this->never())
            ->method('setIsTransactionClosed');

        $this->expectExceptionMessage('Transaction ID not found for order');

        // then
        $this->subject->execute($expectedCommandSubject);
    }
}
