<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Gateway\Command;

use Evidente\Aircash\Gateway\Command\Initialize;
use Magento\Framework\DataObject;
use Magento\Payment\Gateway\Command\CommandException;
use Magento\Payment\Gateway\Data\PaymentDataObject;
use Magento\Sales\Model\Order;
use Magento\Sales\Model\Order\Payment;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

class InitializeTest extends TestCase
{
    /**
     * @var PaymentDataObject|MockObject
     */
    private $payment;

    /**
     * @var Payment|MockObject
     */
    private $orderPayment;

    /**
     * @var Order|MockObject
     */
    private $order;

    /**
     * @var DataObject|MockObject
     */
    private $stateObject;

    /**
     * @var Initialize
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->payment = $this->createMock(PaymentDataObject::class);
        $this->orderPayment = $this->createMock(Payment::class);
        $this->order = $this->createMock(Order::class);

        $this->stateObject = $this
            ->getMockBuilder(DataObject::class)
            ->disableOriginalConstructor()
            ->disableOriginalClone()
            ->disableArgumentCloning()
            ->disallowMockingUnknownTypes()
            ->setMethods([
                'setState',
                'setStatus',
                'setIsNotified'
            ])
            ->getMock();

        $this->subject = new Initialize();
    }

    /**
     * @throws CommandException
     */
    public function testExecute()
    {
        // given
        $this->payment->method('getPayment')->willReturn($this->orderPayment);
        $this->orderPayment->method('getOrder')->willReturn($this->order);

        $commandSubject = [
            'payment' => $this->payment,
            'stateObject' => $this->stateObject,
        ];

        $this
            ->order
            ->expects($this->once())
            ->method('setCustomerNoteNotify')
            ->with(false);

        $this
            ->stateObject
            ->expects($this->once())
            ->method('setState')
            ->with(Order::STATE_PENDING_PAYMENT);

        $this
            ->stateObject
            ->expects($this->once())
            ->method('setStatus')
            ->with(Order::STATE_PENDING_PAYMENT);

        // then
        $this->subject->execute($commandSubject);
    }

    /**
     * @throws CommandException
     * @dataProvider commandSubjectProvider
     */
    public function testExecuteShouldFailBecauseOfInvalidPaymentObject(array $commandSubject, string $exceptionMessage)
    {
        // given
        $this->expectExceptionMessage($exceptionMessage);

        // then
        $this->subject->execute($commandSubject);
    }

    public function commandSubjectProvider(): array
    {
        return [
            [
                [],
                'Payment data object should be provided'
            ],
            [
                ['payment' => 'property'],
                'Payment data object should be provided'
            ]
        ];
    }
}
