<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Gateway\Command;

use Evidente\Aircash\Data\Transaction\CancellationResult;
use Evidente\Aircash\Exception\InvalidInputException;
use Evidente\Aircash\Exception\RequestException;
use Evidente\Aircash\Gateway\Command\Refund;
use Magento\Framework\DataObject;
use Magento\Payment\Gateway\Command\CommandException;

/**
 * @SuppressWarnings(PHPMD)
 */
class RefundTest extends AbstractCommandTest
{
    /**
     * @var Refund
     */
    private $subject;

    protected function setUp(): void
    {
        parent::setUp();
        $this->subject = new Refund(
            $this->aircashClient,
            $this->cancellationRequestFactory,
            $this->refundRequestFactory,
            $this->logger
        );
    }

    /**
     * @throws CommandException
     * @throws InvalidInputException
     * @throws RequestException
     */
    public function testExecute()
    {
        // given
        $expectedCancelTransactionId = 'cancel-transaction-id';
        $expectedWebsiteId = 1;

        $this->storeManager->method('getStore')->willReturn($this->store);
        $this->store->method('getWebsiteId')->willReturn($expectedWebsiteId);

        $expectedCommandSubject = [
            'payment' => new DataObject(['payment' => $this->orderPayment])
        ];

        $this->order->method('getIncrementId')->willReturn('1000000');

        $this
            ->creditMemo
            ->expects($this->once())
            ->method('setTransactionId')
            ->with($expectedCancelTransactionId);

        $this
            ->aircashClient
            ->method('cancelTransaction')
            ->willReturn(new CancellationResult($expectedCancelTransactionId));

        // then
        $this->subject->execute($expectedCommandSubject);
    }

    /**
     * @throws CommandException
     * @throws InvalidInputException
     * @throws RequestException
     */
    public function testExecuteShouldFailOnMissingTransactionId()
    {
        // given
        $expectedCommandSubject = [
            'payment' => new DataObject(['payment' => $this->orderPayment])
        ];

        $expectedWebsiteId = 1;

        $this->storeManager->method('getStore')->willReturn($this->store);
        $this->store->method('getWebsiteId')->willReturn($expectedWebsiteId);

        $this
            ->creditMemo
            ->expects($this->never())
            ->method('setTransactionId');

        $this->expectExceptionMessage('Increment order ID is required for transaction ID');

        // then
        $this->subject->execute($expectedCommandSubject);
    }
}
