<?php
// phpcs:ignorefile

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Model;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Model\ActivationConfig;
use Magento\Framework\App\Config\ScopeConfigInterface;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class ActivationConfigTest extends TestCase
{
    /**
     * @var ScopeConfigInterface|MockObject
     */
    private $scopeConfig;

    /**
     * @var ActivationConfig
     */
    private $subject;

    private $testMode = '1';

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->scopeConfig = $this->createMock(ScopeConfigInterface::class);

        $this->scopeConfig->method('getValue')->willReturnCallback(function ($path) {
            switch ($path) {
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_ACTIVE:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_DEVELOPER_MODE:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_TEST_MODE:
                    return $this->testMode;
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PATH_PARTNER_ID:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/' . ConfigInterface::CONFIG_PATH_PARTNER_ID:
                    return 'partner_id';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PATH_LOCATION_ID:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/' . ConfigInterface::CONFIG_PATH_LOCATION_ID:
                    return 'location_id';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PATH_TRANSACTION_ID_PREFIX:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PASSPHRASE:
                default:
                    return null;
            }
        });

        $this->subject = new ActivationConfig($this->scopeConfig);
    }

    public function testIsActive()
    {
        $this->assertTrue($this->subject->isActive());
    }

    public function testIsTestMode()
    {
        $this->assertTrue($this->subject->isTestMode());
    }

    public function testIsDeveloperMode()
    {
        $this->assertTrue($this->subject->isDeveloperMode());
    }

    public function testGetTransactionIdPrefix()
    {
        $this->assertNull($this->subject->getTransactionIdPrefix());
    }

    public function testGetPartnerID()
    {
        $this->assertSame('partner_id', $this->subject->getPartnerID());
    }

    public function testGetLocationID()
    {
        $this->assertSame('location_id', $this->subject->getLocationID());
    }

    public function testGetPublicKey()
    {
        // given
        $paths = [
            dirname(__FILE__) . '/../../../Model/Partner/Activation/Data/activation_key_prod.pub',
            dirname(__FILE__) . '/../../../Model/Partner/Activation/Data/activation_key_test.pub',
        ];

        // when, then
        foreach ($paths as $index => $path) {
            $this->testMode = (string)$index;
            $this->assertFileIsReadable($path);
            $expectedContents = \file_get_contents($path);
            $contents = $this->subject->getPublicKey();
            $this->assertSame($expectedContents, $contents);
        }
    }

    public function testGetPrivateKey()
    {
        $paths = [
            dirname(__FILE__) . '/../../../Model/Partner/Activation/Data/activation_key_prod',
            dirname(__FILE__) . '/../../../Model/Partner/Activation/Data/activation_key_test',
        ];

        // when, then
        foreach ($paths as $index => $path) {
            $this->testMode = (string)$index;
            $this->assertFileIsReadable($path);
            $expectedContents = \file_get_contents($path);
            $contents = $this->subject->getPrivateKey();
            $this->assertSame($expectedContents, $contents);
        }
    }

    public function testGetPassphrase()
    {
        $this->assertNull($this->subject->getPassphrase());
    }
}
