<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Model;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Api\Data\Partner\ActivationRequestInterface;
use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Api\SignatureInterface;
use Evidente\Aircash\Data\Partner\ActivationRequest;
use Evidente\Aircash\Exception\RequestException;
use Evidente\Aircash\Model\AircashPartnerClient;
use GuzzleHttp\Client;
use GuzzleHttp\Handler\MockHandler;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Response;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Psr\Log\LoggerInterface;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class AircashPartnerClientTest extends TestCase
{
    /**
     * @var Client
     */
    private $client;

    /**
     * @var MockHandler
     */
    private $mockHandler;

    /**
     * @var SignatureInterface|MockObject
     */
    private $signature;

    /**
     * @var ConfigInterface|MockObject
     */
    private $config;

    /**
     * @var LoggerInterface|MockObject
     */
    private $logger;

    /**
     * @var ActivationRequestInterface
     */
    private $activationRequest;

    /**
     * @var AircashPartnerClient
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->signature = $this->createMock(SignatureInterface::class);
        $this->config = $this->createMock(ConfigInterface::class);
        $this->logger = $this->createMock(LoggerInterface::class);

        $this->mockHandler = new MockHandler();

        $handlerStack = HandlerStack::create($this->mockHandler);

        $this->client = new Client(['handler' => $handlerStack]);

        $expectedPublicKey = 'public_key';
        $expectedPhoneNumber = '5554444';
        $expectedContactEmail = 'email@example.com';
        $expectedConfirmTransactionURL = 'example.com';
        $expectedCurrencyID = CodeRequestInterface::CURRENCY_MAPPING[CodeRequestInterface::CURRENCY_EUR];
        $expectedPartnerName = 'partner_name';
        $expectedPartnerID = 'partner_id';
        $expectedPlatformID = 'platform_id';
        $expectedWebsiteId = 1;

        $this->activationRequest = new ActivationRequest(
            $expectedPlatformID,
            $expectedPartnerID,
            $expectedPartnerName,
            $expectedPublicKey,
            $expectedCurrencyID,
            $expectedConfirmTransactionURL,
            $expectedContactEmail,
            $expectedPhoneNumber,
            $expectedWebsiteId
        );

        $this->subject = new AircashPartnerClient(
            $this->signature,
            $this->config,
            $this->logger,
            $this->client
        );
    }

    /**
     * @throws RequestException
     */
    public function testActivatePartner()
    {
        // given
        $this->mockHandler->append(
            new Response(200)
        );

        $this
            ->signature
            ->expects($this->once())
            ->method('sign')
            ->willReturn('signature');

        // when, then
        $this->subject->activatePartner($this->activationRequest);
    }
}
