<?php
// phpcs:ignorefile

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\Model;

use Evidente\Aircash\Api\ConfigInterface;
use Evidente\Aircash\Model\Config;
use Magento\Framework\App\Config\ScopeConfigInterface;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class ConfigTest extends TestCase
{
    /**
     * @var ScopeConfigInterface|MockObject
     */
    private $scopeConfig;

    /**
     * @var ConfigInterface
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->scopeConfig = $this->createMock(ScopeConfigInterface::class);

        $this->scopeConfig->method('getValue')->willReturnCallback(function ($path) {
            switch ($path) {
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_ACTIVE:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_DEVELOPER_MODE:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_TEST_MODE:
                    return '1';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PATH_PARTNER_ID:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/' . ConfigInterface::CONFIG_PATH_PARTNER_ID:
                    return 'partner_id';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PATH_LOCATION_ID:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/' . ConfigInterface::CONFIG_PATH_LOCATION_ID:
                    return 'location_id';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_PROD . '/' . ConfigInterface::CONFIG_PRIVATE_KEY:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_GROUP_TEST . '/' . ConfigInterface::CONFIG_PRIVATE_KEY:
                    return 'private_key';
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PATH_TRANSACTION_ID_PREFIX:
                case ConfigInterface::CONFIG_PATH_BASE . ConfigInterface::CONFIG_PASSPHRASE:
                default:
                    return null;
            }
        });

        $this->subject = new Config($this->scopeConfig);
    }

    public function testIsActive()
    {
        $this->assertTrue($this->subject->isActive());
    }

    public function testIsTestMode()
    {
        $this->assertTrue($this->subject->isTestMode());
    }

    public function testIsDeveloperMode()
    {
        $this->assertTrue($this->subject->isDeveloperMode());
    }

    public function testGetTransactionIdPrefix()
    {
        $this->assertNull($this->subject->getTransactionIdPrefix());
    }

    public function testGetPartnerID()
    {
        $this->assertSame('partner_id', $this->subject->getPartnerID());
    }

    public function testGetLocationID()
    {
        $this->assertSame('location_id', $this->subject->getLocationID());
    }

    public function testGetPrivateKey()
    {
        $this->assertSame('private_key', $this->subject->getPrivateKey());
    }

    public function testGetPassphrase()
    {
        $this->assertNull($this->subject->getPassphrase());
    }
}
