<?php

declare(strict_types=1);

namespace Evidente\Aircash\Test\Unit\ViewModel\Checkout;

use Evidente\Aircash\Api\Rest\CheckoutDataProviderInterface;
use Evidente\Aircash\Data\Transaction\CodeResult;
use Evidente\Aircash\Exception\PaymentExpiredException;
use Evidente\Aircash\ViewModel\Checkout\PaymentViewModel;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Locale\Resolver;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use ReflectionException;

/**
 * @SuppressWarnings(PHPMD)
 */
class PaymentViewModelTest extends TestCase
{
    /**
     * @var CheckoutDataProviderInterface|MockObject
     */
    private $checkoutDataProvider;

    /**
     * @var Resolver|MockObject
     */
    private $localeResolver;

    /**
     * @var PaymentViewModel
     */
    private $subject;

    /**
     * @throws ReflectionException
     */
    protected function setUp(): void
    {
        $this->checkoutDataProvider = $this->createMock(CheckoutDataProviderInterface::class);
        $this->localeResolver = $this->createMock(Resolver::class);

        $this->subject = new PaymentViewModel(
            $this->checkoutDataProvider,
            $this->localeResolver
        );
    }

    /**
     * @throws LocalizedException
     * @throws PaymentExpiredException
     */
    public function testGetCodeLinkShouldThrowOnFailure()
    {
        // given
        $this->checkoutDataProvider->method('getCode')->willThrowException(
            new LocalizedException(__('Exception'))
        );

        $this->expectException('Exception');

        // when, then
        $this->assertNull($this->subject->getCodeLink());
    }

    /**
     * @throws LocalizedException
     * @throws PaymentExpiredException
     */
    public function testGetCodeLink()
    {
        // given
        $expectedCodeLink = 'link';
        $expectedCodeResult = new CodeResult($expectedCodeLink);

        $this
            ->checkoutDataProvider
            ->expects($this->once())
            ->method('getCode')
            ->willReturn($expectedCodeResult);

        // when
        $result = $this->subject->getCodeLink();

        // then
        $this->assertSame($expectedCodeLink, $result);
    }

    /**
     * @dataProvider getLocales
     */
    public function testGetLocale(string $inputLocale, string $expectedOutputLocale)
    {
        // given
        $this->localeResolver->method('getLocale')->willReturn($inputLocale);

        // when
        $result = $this->subject->getLocale();

        // then
        $this->assertSame($expectedOutputLocale, $result);
    }

    public static function getLocales()
    {
        return [
            ['hr_HR', 'hr'],
            ['en_US', 'en'],
            ['fr_FR', 'en'],
        ];
    }
}
