<?php

declare(strict_types=1);

namespace Evidente\Aircash\ViewModel\Checkout;

use Evidente\Aircash\Api\Data\Transaction\CodeRequestInterface;
use Evidente\Aircash\Api\Rest\CheckoutDataProviderInterface;
use Evidente\Aircash\Exception\PaymentExpiredException;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Framework\Locale\Resolver as LocaleResolver;

class PaymentViewModel implements ArgumentInterface
{
    /**
     * @var CheckoutDataProviderInterface
     */
    private $checkoutDataProvider;

    /**
     * @var LocaleResolver
     */
    private $localeResolver;

    public function __construct(
        CheckoutDataProviderInterface $checkoutDataProvider,
        LocaleResolver $localeResolver
    ) {
        $this->checkoutDataProvider = $checkoutDataProvider;
        $this->localeResolver = $localeResolver;
    }

    public function getLastCodeRequest(): ?CodeRequestInterface
    {
        return $this->checkoutDataProvider->getLastCodeRequest();
    }

    /**
     * @throws LocalizedException
     * @throws PaymentExpiredException
     */
    public function getCodeLink(): ?string
    {
        return $this->checkoutDataProvider->getCode()->getCodeLink();
    }

    public function getLocale(): string
    {
        $locale = $this->localeResolver->getLocale();
        $shortLocale = strstr($locale, '_', true);

        if (!in_array($shortLocale, ['hr', 'en'])) {
            $shortLocale = 'en';
        }

        return $shortLocale;
    }
}
