define(
    [
        'jquery',
        'ko',
        'Evidente_Aircash/js/model/qrcode',
        'uiComponent',
        'mage/url'
    ],
    function (
        $,
        ko,
        qrcodeModel,
        Component,
        mageUrl
    ) {
        'use strict';

        const isMobilePhone = navigator.userAgent.match(/iPhone|iPad|iPod|Android|Dalvik/);

        return Component.extend({
            defaults: {
                template: 'Evidente_Aircash/checkout/payment',
                paymentUrl: null,
                isMobile: isMobilePhone,
                storeLocale: 'en',
                validForPeriod: 5,
                countdownDisplay: ko.observable(''),
                pollingTimer: null,
                redirectUrlOnInvalidResponse: 'checkout/cart',
                redirectUrlOnSuccess: 'checkout/onepage/success',
                redirectUrlOnExpire: 'aircash/checkout/expired',
                statusUrl: 'aircash/checkout/status'
            },

            afterRender: function () {
                let self = this;

                if (!self.isMobile) {
                    let qrCodeEl = this.getQRcode(this.paymentUrl);
                    $('#aircash-checkout-qr').html(qrCodeEl);
                }

                $('.loading-mask').hide();

                self.countdown(self.validForPeriod * 60);

                self.waitForPayment();
            },

            getQRcode: function (content) {
                let qrCodeEl = document.createElement('div');
                qrCodeEl.className = 'aircash-qr-image';

                new qrcodeModel.QRCode(qrCodeEl, {
                    text: content,
                    width: 180,
                    height: 180,
                    correctLevel: qrcodeModel.QRCode.CorrectLevel.L
                });

                // remove qrCode content hints while hovering
                qrCodeEl.removeAttribute("title");
                qrCodeEl.getElementsByTagName("img")[0].removeAttribute("alt");

                return qrCodeEl;
            },

            redirectToPaymentUrl: function () {
                $.mage.redirect(mageUrl.build(this.paymentUrl));
            },

            getStoreLocale() {
                return this.storeLocale;
            },

            waitForPayment() {
                let self = this;

                $.get(mageUrl.build(self.statusUrl), function (data) {
                    if (data.status !== undefined) {
                        const status = data.status;

                        if (status === 'invalid') {
                            self.stopPolling();
                            $.mage.redirect(mageUrl.build(self.redirectUrlOnInvalidResponse));
                        } else if (status === 'complete') {
                            self.stopPolling();
                            $.mage.redirect(mageUrl.build(self.redirectUrlOnSuccess));

                        }
                    }
                }).always(function () {
                    self.pollingTimer = setTimeout(function () {
                        self.waitForPayment()
                    }, 2000);
                });
            },

            stopPolling() {
                if (this.pollingTimer) {
                    clearTimeout(this.pollingTimer);
                }
            },

            expirePayment() {
                this.stopPolling();
                $.mage.redirect(mageUrl.build(this.redirectUrlOnExpire));
            },

            countdown(duration) {
                let timer = duration, minutes, seconds;
                let self = this;

                let countdownInterval = setInterval(function () {
                    minutes = parseInt(timer / 60, 10);
                    seconds = parseInt(timer % 60, 10);

                    minutes = minutes < 10 ? "0" + minutes : minutes;
                    seconds = seconds < 10 ? "0" + seconds : seconds;

                    self.countdownDisplay(minutes + ":" + seconds);

                    if (--timer < 0) {
                        clearInterval(countdownInterval);
                        self.expirePayment();
                    }
                }, 1000);
            }
        });
    }
);
